@@ -89,7 +89,7 @@ import org.gjt.sp.util.ThreadUtilities;
  * @see View#getEditPanes()
  *
  * @author Slava Pestov
- * @version $Id: EditPane.java 22181 2012-09-09 23:29:58Z ezust $
+ * @version $Id: EditPane.java 23981 2015-08-10 14:56:24Z daleanson $
  */
 public class EditPane extends JPanel implements BufferSetListener
 {
@@ -220,7 +220,7 @@ public class EditPane extends JPanel implements BufferSetListener
 					// This must happen after loadCaretInfo.
 					// Otherwise caret is not restored properly.
 					int check = jEdit.getIntegerProperty("checkFileStatus");
-					if (jEdit.isStartupDone() && (check & GeneralOptionPane.checkFileStatus_focusBuffer) > 0);
+					if (jEdit.isStartupDone() && (check & GeneralOptionPane.checkFileStatus_focusBuffer) > 0)
 						jEdit.checkBufferStatus(view, true);
 				}
 			});
@@ -494,6 +494,7 @@ public class EditPane extends JPanel implements BufferSetListener
 	//{{{ goToNextMarker() method
 	/**
 	 * Moves the caret to the next marker.
+	 * @param select whether to select the marker
 	 * @since jEdit 4.3pre3
 	 */
 	public void goToNextMarker(boolean select)
@@ -509,10 +510,9 @@ public class EditPane extends JPanel implements BufferSetListener
 
 		int caret = textArea.getCaretPosition();
 
-		for(int i = 0; i < markers.size(); i++)
+		for (Marker _marker : markers)
 		{
-			Marker _marker = markers.get(i);
-			if(_marker.getPosition() > caret)
+			if (_marker.getPosition() > caret)
 			{
 				marker = _marker;
 				break;
@@ -532,6 +532,7 @@ public class EditPane extends JPanel implements BufferSetListener
 	//{{{ goToPrevMarker() method
 	/**
 	 * Moves the caret to the previous marker.
+	 * @param select whether to select the marker
 	 * @since jEdit 2.7pre2
 	 */
 	public void goToPrevMarker(boolean select)
@@ -603,17 +604,15 @@ public class EditPane extends JPanel implements BufferSetListener
 
 		// always add markers on selected lines
 		Selection[] selection = textArea.getSelection();
-		for(int i = 0; i < selection.length; i++)
+		for (Selection s : selection)
 		{
-			Selection s = selection[i];
 			int startLine = s.getStartLine();
-			if(startLine != s.getEndLine() && startLine != caretLine)
+			if (startLine != s.getEndLine() && startLine != caretLine)
 			{
-				buffer.addMarker('\0',s.getStart());
+				buffer.addMarker('\0', s.getStart());
 			}
 
-			if(s.getEndLine() != caretLine)
-				buffer.addMarker('\0',s.getEnd());
+			if (s.getEndLine() != caretLine) buffer.addMarker('\0', s.getEnd());
 		}
 
 		// toggle marker on caret line
@@ -773,36 +772,36 @@ public class EditPane extends JPanel implements BufferSetListener
 	EditPane(@Nonnull View view, @Nullable BufferSet bufferSetSource, @Nonnull Buffer buffer)
 	{
 		super(new BorderLayout());
-        BufferSet.Scope scope = jEdit.getBufferSetManager().getScope();
-        BufferSet source = bufferSetSource;
-        switch (scope)
-        {
-            case editpane:
-                // do nothing
-                break;
-            case view:
-                {
-                    EditPane editPane = view.getEditPane();
-                    if (editPane != null)
-                    {
-                        // if we have an editpane we copy it
-                        source = editPane.getBufferSet();
-                    }
-                }
-                break;
-            case global:
-                View activeView = jEdit.getActiveView();
-                if (activeView != null)
-                {
-                    EditPane editPane = activeView.getEditPane();
-                    if (editPane != null)
-                    {
-                        source = editPane.getBufferSet();
-                    }
-                }
-                break;
-        }
-        bufferSet = new BufferSet(source);
+		BufferSet.Scope scope = jEdit.getBufferSetManager().getScope();
+		BufferSet source = bufferSetSource;
+		switch (scope)
+		{
+			case editpane:
+				// do nothing
+				break;
+			case view:
+				{
+					EditPane editPane = view.getEditPane();
+					if (editPane != null)
+					{
+						// if we have an editpane we copy it
+						source = editPane.getBufferSet();
+					}
+				}
+				break;
+			case global:
+				View activeView = jEdit.getActiveView();
+				if (activeView != null)
+				{
+					EditPane editPane = activeView.getEditPane();
+					if (editPane != null)
+					{
+						source = editPane.getBufferSet();
+					}
+				}
+				break;
+		}
+		bufferSet = new BufferSet(source);
 
 		init = true;
 
@@ -906,8 +905,9 @@ public class EditPane extends JPanel implements BufferSetListener
 			"view.gutter.structureHighlight"));
 		gutter.setStructureHighlightColor(
 			jEdit.getColorProperty("view.gutter.structureHighlightColor"));
-		gutter.setBackground(
-			jEdit.getColorProperty("view.gutter.bgColor"));
+		Color backgroundColor = jEdit.getColorProperty("view.gutter.bgColor");
+		gutter.setBackground(backgroundColor);
+		textArea.setBackground(backgroundColor);
 		gutter.setForeground(
 			jEdit.getColorProperty("view.gutter.fgColor"));
 		gutter.setHighlightedForeground(
@@ -1001,6 +1001,8 @@ public class EditPane extends JPanel implements BufferSetListener
 			jEdit.getColorProperty("view.structureHighlightColor"));
 		painter.setEOLMarkersPainted(jEdit.getBooleanProperty(
 			"view.eolMarkers"));
+		painter.setEOLMarkerChar(
+			jEdit.getProperty("view.eolMarkerChar", "·"));
 		painter.setEOLMarkerColor(
 			jEdit.getColorProperty("view.eolMarkerColor"));
 		painter.setWrapGuidePainted(jEdit.getBooleanProperty(
