@@ -27,9 +27,9 @@ package org.gjt.sp.jedit;
 
 //{{{ Imports
 import java.io.*;
-import java.io.File;
-import java.io.IOException;
 import java.net.MalformedURLException;
+import java.net.URI;
+import java.net.URISyntaxException;
 import java.net.URL;
 import java.nio.charset.MalformedInputException;
 import java.util.*;
@@ -57,7 +57,7 @@ import org.gjt.sp.util.StringList;
  * <li>{@link #constructPath(String,String)}</li>
  * </ul>
  *
- * @version $Id: MiscUtilities.java 22828 2013-03-05 19:40:05Z ezust $
+ * @version $Id: MiscUtilities.java 23981 2015-08-10 14:56:24Z daleanson $
  */
 public class MiscUtilities
 {
@@ -126,14 +126,30 @@ public class MiscUtilities
 	static final Pattern varPattern2 = Pattern.compile(varPatternString2);
 	static final Pattern winPattern = Pattern.compile(winPatternString);
 
-	/** Accepts a string from the user which may contain variables of various syntaxes.
-	 *  The function supports the following expansion syntaxes:
+
+	/** A helper function for expandVariables when handling Windows paths on non-windows systems.
+	*/
+	private static String win2unix(String winPath)
+	{
+		String unixPath = winPath.replace('\\', '/');
+		Matcher m = winPattern.matcher(unixPath);
+		if (m.find())
+		{
+			String varName = m.group(2);
+			String expansion = System.getenv(varName);
+			if (expansion != null)
+				return m.replaceFirst(expansion);
+		}
+		return unixPath;
+	}
+
+	/** Accepts a string from the user (or a settings file) which may contain a variable-prefix path of various syntaxes. Performs the reverse of abbreviate() from any platform.
+	 *  The function supports the following prefix syntaxes:
 	 *     ~/ or ~\   expand to user.home
-	 *     $varname
-	 *     ${varname} (on non-windows)
-	 *     %varname% (on Windows)
-	 *     And expand each of these by looking at the system environment variables for possible
-	 *     expansions.
+	 *     $varname (all platforms)
+	 *     %varname% (all platforms)
+	 *     ${varname} (non-Windows platforms)
+	 *     And expand each of these by looking at the system environment variables for possible expansions.
 	 *     @return a string which is either the unchanged input string, or one with expanded variables.
 	 *     @since jEdit 4.3
 	 *     @see #abbreviate
@@ -143,8 +159,12 @@ public class MiscUtilities
 	{
 		if (arg.startsWith("~/") || arg.startsWith("~\\"))
 			return System.getProperty("user.home") + arg.substring(1);
+
+		Matcher m = winPattern.matcher(arg);
+		if (!OperatingSystem.isWindows() && m.find() )
+			return win2unix(arg);
 		Pattern p = varPattern;
-		Matcher m = p.matcher(arg);
+		m = p.matcher(arg);
 		if (!m.find())
 		{
 			if (OperatingSystem.isWindows())
@@ -172,10 +192,13 @@ public class MiscUtilities
 	} //}}}
 
 	//{{{ abbreviate() methods
-	/** @return an abbreviated path, replacing values with variables, if a prefix exists.
-		uses platform convention (%varname% on windows, $varname on other platforms)
+	/** The reverse of expandVariables(), returns a shortened path if possible.
+	 *
+	 *  Uses platform convention (%varname% on windows, $varname on other platforms)
+	 *
+	 *	@return an abbreviated path, replacing values with variables, if a prefix exists.
 	 *  @see #expandVariables
-	 *  @since jEdit 4.3pre16
+	 *  @since jEdit 4.3
 	 */
 	public static String abbreviate(String path)
 	{
@@ -183,15 +206,15 @@ public class MiscUtilities
 			svc = new VarCompressor();
 		return svc.compress(path);
 	}
-	
-	/** Same as abbreviate() but checks a view option which can 
-	 * disable the feature for things jEdit UI components.
-	 * 
+
+	/** Same as abbreviate() but checks a view option which can
+	 *  disable the feature for jEdit UI components.
+	 *  @since jEdit 5.1
 	 */
 	public static String abbreviateView(String path)
 	{
 		if (!jEdit.getBooleanProperty("view.abbreviatePaths")) return path;
-		return abbreviate(path);		
+		return abbreviate(path);
 	} //}}}
 
 	//{{{ resolveSymlinks() method
@@ -585,14 +608,16 @@ public class MiscUtilities
 	} //}}}
 
 	//{{{ openInDesktop() method
-	/** Opens a file using the desktop file associations.
+	/** Opens a file or URI using the desktop file associations.
 		<p>
 		Uses native desktop commands for each platform, which ask the user to choose an
 		association for files that do not already have one, using the desktop's
 		dialog, in contrast to Desktop.open() which just throws an IOException
 		for unknown types.
 
-		@param path path or URL (supported on Linux, anyway) of thing to open
+		If a URI is supplied, use desktop browser.
+
+		@param path: path or URI of thing to open/browse
 		@author Alan Ezust
 		@since jEdit 5.0
 	*/
@@ -601,18 +626,30 @@ public class MiscUtilities
 		StringList sl = new StringList();
 		if (OperatingSystem.isWindows())
 		{
-			sl.add("rundll32");
-			sl.add("SHELL32.DLL,ShellExec_RunDLL");
+			if (MiscUtilities.isURL(path)) try {
+				URI uri = new URI(path);
+				java.awt.Desktop.getDesktop().browse(uri);
+				return;
+			}
+			catch (IOException ioe) {
+				Log.log(Log.ERROR, path, "Can't open URI", ioe);
+			} catch (URISyntaxException use) {
+				Log.log(Log.ERROR, path, "Bad URI syntax:", use);
+			}
+			else {
+				sl.add("rundll32");
+				sl.add("SHELL32.DLL,ShellExec_RunDLL");
+			}
 		}
 		else if (OperatingSystem.isMacOS())
 			sl.add("open");
 		else if (OperatingSystem.isX11())
 		{
 			/* For gnome, use gnome-open. Need a way of testing that gnome is actually
-			   running though. Otherwise it is not the correct program to use. 
+			   running though. Otherwise it is not the correct program to use.
 			File f = new File("/usr/bin/gnome-open");
 			if (f.exists()) sl.add("gnome-open");
-			else */ 
+			else */
 			sl.add("xdg-open");
 		}
 		try
@@ -719,7 +756,7 @@ public class MiscUtilities
 	 * Checks whether the last backup was not earlier than
 	 * <code>backupTimeDistance</code> ms ago.
 	 * @param path The file to back up.
-	 * @param backups The number of backups. Must be >= 1. If > 1, backup
+	 * @param backups The number of backups. Must be &gt;= 1. If &gt; 1, backup
 	 * files will be numbered.
 	 * @param backupDirectory The directory determined externally or
 	 * obtained from <code>prepareBackupDirectory</code>.
@@ -811,7 +848,7 @@ public class MiscUtilities
 	/**
 	 * Saves a backup (optionally numbered) of a file.
 	 * @param file A local file
-	 * @param backups The number of backups. Must be >= 1. If > 1, backup
+	 * @param backups The number of backups. Must be &gt;= 1. If &gt; 1, backup
 	 * files will be numbered.
 	 * @param backupPrefix The backup file name prefix
 	 * @param backupSuffix The backup file name suffix
@@ -830,7 +867,7 @@ public class MiscUtilities
 	 * Saves a backup (optionally numbered) of a file. Requires
 	 * specifying the backup directory and generates the backup filename.
 	 * @param file A local file
-	 * @param backups The number of backups. Must be >= 1. If > 1, backup
+	 * @param backups The number of backups. Must be &gt;= 1. If &gt; 1, backup
 	 * files will be numbered.
 	 * @param backupPrefix The backup file name prefix
 	 * @param backupSuffix The backup file name suffix
@@ -1468,6 +1505,27 @@ loop:		for(;;)
 
 	//}}}
 
+	//{{{ storeProperties() method
+	/**
+	 * Stores properties with sorted keys.
+     * @param props  Given properties.
+     * @param out  Output stream.
+     * @param comments  Description of the property list.
+     * @since jEdit 5.3
+	 */
+	public static void storeProperties(Properties props, OutputStream out, String comments)
+        throws IOException
+	{
+		Properties sorted = new Properties() {
+			@Override
+			public synchronized Enumeration<Object> keys() {
+				return Collections.enumeration(new TreeSet<Object>(super.keySet()));
+			}
+		};
+		sorted.putAll(props);
+		sorted.store(out, comments);
+	} //}}}
+
 	static VarCompressor svc = null;
 
 	//{{{ VarCompressor class
