@@ -25,11 +25,7 @@ package org.gjt.sp.jedit;
 
 //{{{ Imports
 import java.lang.reflect.Method;
-import java.util.Hashtable;
-import java.util.Collections;
-import java.util.LinkedList;
-import java.util.List;
-import java.util.Map;
+import java.util.*;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 import java.util.regex.PatternSyntaxException;
@@ -48,7 +44,7 @@ import org.gjt.sp.util.StandardUtilities;
  * One instance of this class is created for each supported edit mode.
  *
  * @author Slava Pestov
- * @version $Id: Mode.java 22949 2013-04-23 18:53:15Z thomasmey $
+ * @version $Id: Mode.java 23980 2015-08-10 13:44:17Z daleanson $
  */
 public class Mode
 {
@@ -64,7 +60,7 @@ public class Mode
 	{
 		this.name = name;
 		this.ignoreWhitespace = true;
-		props = new Hashtable<String, Object>();
+		props = new Hashtable<>();
 	} //}}}
 
 	//{{{ init() method
@@ -89,7 +85,9 @@ public class Mode
 				{
 					// replace path separators by both separator possibilities in the regex
 					filepathRE = filepathRE.replaceAll("/|\\\\\\\\", "[/\\\\\\\\]");
-				} else {
+				}
+				else
+				{
 					// glob is for a filename without path, prepend the regex with
 					// an optional path prefix to be able to match against full paths
 					filepathRE = String.format("(?:.*[/\\\\])?%s", filepathRE);
@@ -156,6 +154,18 @@ public class Mode
 		}
 	} //}}}
 
+	//{{{ isUserMode method
+	public boolean isUserMode() 
+	{
+		return isUserMode;	
+	} //}}}
+	
+	//{{{ setUserMode method
+	public void setUserMode(boolean b) 
+	{
+		isUserMode = b;	
+	} //}}}
+	
 	//{{{ getProperty() method
 	/**
 	 * Returns a mode property.
@@ -325,7 +335,7 @@ public class Mode
 			int lastWindowsPos = filePath.lastIndexOf('\\');
 			int index = Math.max(lastUnixPos, lastWindowsPos);
 			String filename = filePath.substring(index + 1);
-			return filename != null && filename.equalsIgnoreCase(filenameGlob);
+			return filename.equalsIgnoreCase(filenameGlob);
 		}
 
 		return false;
@@ -394,9 +404,9 @@ public class Mode
 			};
 
 			StringBuilder buf = new StringBuilder();
-			for(int i = 0; i < props.length; i++)
+			for (String prop1 : props)
 			{
-				String prop = (String) getProperty(props[i]);
+				String prop = (String) getProperty(prop1);
 				if (prop != null)
 					buf.append(prop);
 			}
@@ -431,10 +441,8 @@ public class Mode
 			"unalignedCloseBracket",
 		};
 
-		for(int i = 0; i < bracketProps.length; i++)
-		{
-			createBracketIndentRules(bracketProps[i], rules);
-		}
+		for (String bracketProp : bracketProps)
+			createBracketIndentRules(bracketProp, rules);
 
 		String[] finalProps = {
 			"unindentThisLine",
@@ -479,7 +487,7 @@ public class Mode
 			if(value != null)
 			{
 				Method m = IndentRuleFactory.class.getMethod(
-					prop,new Class[] { String.class });
+					prop, String.class);
 				return (IndentRule)m.invoke(null, value);
 			}
 		}
@@ -495,7 +503,7 @@ public class Mode
 
 	//{{{ createBracketIndentRules() method
 	private void createBracketIndentRules(String prop,
-						List<IndentRule> rules)
+						Collection<IndentRule> rules)
 	{
 		String value = (String) getProperty(prop + 's');
 
@@ -508,7 +516,7 @@ public class Mode
 					char ch = value.charAt(i);
 
 					Method m = IndentRuleFactory.class.getMethod(
-						prop,new Class[] { char.class });
+						prop, char.class);
 					rules.add((IndentRule) m.invoke(null, ch));
 				}
 			}
@@ -532,5 +540,6 @@ public class Mode
 	private List<IndentRule> indentRules;
 	private String electricKeys;
 	private boolean ignoreWhitespace;
+	private boolean isUserMode;
 	//}}}
 }
