@@ -36,7 +36,7 @@ import org.gjt.sp.util.StandardUtilities;
 
 /**
  * @author Slava Pestov
- * @version $Id: VFSDirectoryEntryTableModel.java 21831 2012-06-18 22:54:17Z ezust $
+ * @version $Id: VFSDirectoryEntryTableModel.java 23970 2015-08-08 18:10:36Z daleanson $
  * @since jEdit 4.2pre1
  */
 public class VFSDirectoryEntryTableModel extends AbstractTableModel
@@ -272,6 +272,18 @@ public class VFSDirectoryEntryTableModel extends AbstractTableModel
 			+ extAttr + ".width",w);
 	} //}}}
 	
+	//{{{ columnMoved() method
+	protected void columnMoved(int from, int to) {
+		if (from == to)
+			return;
+		if (from < 1 || from > getColumnCount())
+			return;
+		if (to < 1 || to > getColumnCount())
+			return;
+		ExtendedAttribute ea = extAttrs.remove(from - 1);
+		extAttrs.add(to - 1, ea);
+	} //}}}
+	
 	//{{{ getFiles() method
 	public VFSFile[] getFiles()
 	{
@@ -446,9 +458,9 @@ vfs_attr_loop:	for(int i = 0; i < attrs.length; i++)
 			// if the modified attribute is present, then we have a LocalFile
 			if(sortAttribute == VFS.EA_MODIFIED)
 				result = (
-					(Long)((FileVFS.LocalFile)file1).getModified())
+					(Long)file1.getModified())
 					.compareTo(
-					(Long)((FileVFS.LocalFile)file2).getModified());
+					(Long)file2.getModified());
 			// sort by size
 			else if(sortAttribute == VFS.EA_SIZE)
 				result = (
