@@ -41,7 +41,7 @@ import org.gjt.sp.util.Log;
 
 /** An abstract options dialog box.
  * @author Slava Pestov
- * @version $Id: OptionsDialog.java 21831 2012-06-18 22:54:17Z ezust $
+ * @version $Id: OptionsDialog.java 23923 2015-05-22 14:10:47Z ezust $
  * @todo refactor to use OptionGroupPane
  */
 public abstract class OptionsDialog extends EnhancedDialog
@@ -90,13 +90,11 @@ public abstract class OptionsDialog extends EnhancedDialog
 	{
 		getDefaultGroup().addOptionPane(pane);
 	} //}}}
-
+	
 	//{{{ ok() method
 	@Override
 	public void ok()
 	{
-		if(currentPane != null)
-			jEdit.setProperty(name + ".last",currentPane.getName());
 		ok(true);
 	} //}}}
 
@@ -112,6 +110,9 @@ public abstract class OptionsDialog extends EnhancedDialog
 	//{{{ ok() method
 	public void ok(boolean dispose)
 	{
+		if(currentPane != null)
+			jEdit.setProperty(name + ".last",currentPane.getName());
+	
 		OptionTreeModel m = (OptionTreeModel) paneTree
 			.getModel();
 		save(m.getRoot());
@@ -294,15 +295,18 @@ public abstract class OptionsDialog extends EnhancedDialog
 	protected void init(String name, String pane)
 	{
 		this.name = name;
-
 		deferredOptionPanes = new HashMap<Object, OptionPane>();
 
+		if (pane == null) 
+			pane = jEdit.getProperty(name + ".last");		
+		
 		JPanel content = new JPanel(new BorderLayout(12,12));
 		content.setBorder(new EmptyBorder(12,12,12,12));
 		setContentPane(content);
 		stage = new JScrollPane();
 
 		paneTree = new JTree(createOptionTreeModel());
+		paneTree.setRowHeight(0);
 		paneTree.setVisibleRowCount(1);
 		paneTree.setCellRenderer(new PaneNameRenderer());
 
