@@ -72,7 +72,7 @@ import org.gjt.sp.util.StandardUtilities;
 /** A container for dockable windows. This class should never be used
  * directly.
  * @author Slava Pestov
- * @version $Id: PanelWindowContainer.java 21831 2012-06-18 22:54:17Z ezust $
+ * @version $Id: PanelWindowContainer.java 23717 2014-11-02 19:42:53Z ezust $
  * @since jEdit 4.0pre1
  */
 public class PanelWindowContainer implements DockableWindowContainer, DockingArea
@@ -95,6 +95,7 @@ public class PanelWindowContainer implements DockableWindowContainer, DockingAre
 			closeBox.putClientProperty("JButton.buttonType","toolbar");
 
 		closeBox.setMargin(new Insets(0,0,0,0));
+		GUIUtilities.setButtonContentMargin(closeBox, closeBox.getMargin());
 
 		closeBox.addActionListener(new ActionHandler());
 
@@ -105,6 +106,7 @@ public class PanelWindowContainer implements DockableWindowContainer, DockingAre
 			menuBtn.putClientProperty("JButton.buttonType","toolbar");
 
 		menuBtn.setMargin(new Insets(0,0,0,0));
+		GUIUtilities.setButtonContentMargin(menuBtn, menuBtn.getMargin());
 
 		menuBtn.addMouseListener(new MenuMouseHandler());
 
@@ -148,6 +150,7 @@ public class PanelWindowContainer implements DockableWindowContainer, DockingAre
 
 		JToggleButton button = new JToggleButton();
 		button.setMargin(new Insets(1,1,1,1));
+		GUIUtilities.setButtonContentMargin(button, new Insets(6,6,6,6));
 		button.setRequestFocusEnabled(false);
 		button.setIcon(new RotatedTextIcon(rotation,button.getFont(),
 			entry.shortTitle()));
@@ -389,10 +392,8 @@ public class PanelWindowContainer implements DockableWindowContainer, DockingAre
 		buttonPanel.add(closeBox);
 		buttonPanel.add(menuBtn);
 		Collections.sort(buttons,new DockableWindowCompare());
-		for(int i = 0; i < buttons.size(); i++)
-		{
-			buttonPanel.add(buttons.get(i));
-		}
+		for (AbstractButton button : buttons)
+			buttonPanel.add(button);
 	} //}}}
 
 	//{{{ getWrappedDimension() method
@@ -820,10 +821,8 @@ public class PanelWindowContainer implements DockableWindowContainer, DockingAre
 			Component[] comp = parent.getComponents();
 			if(comp.length <= 2)
 			{
-				for(int i = 0; i < comp.length; i++)
-				{
-					comp[i].setVisible(false);
-				}
+				for (Component aComp : comp)
+					aComp.setVisible(false);
 				return;
 			}
 
