@@ -23,7 +23,10 @@
 package org.gjt.sp.jedit.gui.statusbar;
 
 //{{{ Imports
+import org.gjt.sp.jedit.ActionSet;
 import org.gjt.sp.jedit.EditAction;
+import org.gjt.sp.jedit.JEditActionSet;
+import org.gjt.sp.jedit.JEditBeanShellAction;
 import org.gjt.sp.jedit.Registers;
 import org.gjt.sp.jedit.View;
 import org.gjt.sp.jedit.jEdit;
@@ -31,8 +34,10 @@ import org.gjt.sp.jedit.GUIUtilities;
 import org.gjt.sp.jedit.gui.EnhancedDialog;
 import org.gjt.sp.jedit.syntax.SyntaxStyle;
 import org.gjt.sp.jedit.textarea.JEditEmbeddedTextArea;
+import org.gjt.sp.jedit.textarea.StandaloneTextArea;
 import org.gjt.sp.jedit.textarea.TextArea;
 import org.gjt.sp.util.Log;
+import org.jedit.keymap.Keymap;
 
 import javax.swing.*;
 import java.awt.*;
@@ -212,6 +217,19 @@ public class ErrorsWidgetFactory implements StatusWidgetFactory
 			printStream = new PrintStream(byteArrayOutputStream);
 			throwables = Log.throwables.toArray();
 			textArea = new JEditEmbeddedTextArea();
+			JEditActionSet<JEditBeanShellAction> actionSet = new StandaloneTextArea.StandaloneActionSet(jEdit.getPropertyManager(),
+																										textArea,
+																										TextArea.class.getResource("textarea.actions.xml"));
+			textArea.addActionSet(actionSet);
+			actionSet.load();
+			actionSet.initKeyBindings();
+			Keymap keymap = jEdit.getKeymapManager().getKeymap();
+			String shortcut = keymap.getShortcut("copy.shortcut");
+			if (shortcut != null)
+				textArea.getInputHandler().addKeyBinding(shortcut, "copy");
+			String shortcut2 = keymap.getShortcut("copy.shortcut2");
+			if (shortcut2 != null)
+				textArea.getInputHandler().addKeyBinding(shortcut2, "copy");
 
 			JPopupMenu menu = new JPopupMenu();
 			JMenuItem copy = new JMenuItem(jEdit.getProperty("copy.label").replace("$",""));
