@@ -62,6 +62,7 @@ public class HelpTOCPanel extends JPanel
 		if(!OperatingSystem.isMacOSLF())
 			toc.putClientProperty("JTree.lineStyle", "Angled");
 
+		toc.setRowHeight(0);
 		toc.setCellRenderer(new TOCCellRenderer());
 		toc.setEditable(false);
 		toc.setShowsRootHandles(true);
@@ -175,21 +176,16 @@ public class HelpTOCPanel extends JPanel
 		DefaultMutableTreeNode pluginTree = new DefaultMutableTreeNode(
 			jEdit.getProperty("helpviewer.toc.plugins"),true);
 
-		for(int i = 0; i < plugins.length; i++)
+		for (EditPlugin plugin : plugins)
 		{
-			EditPlugin plugin = plugins[i];
-
 			String name = plugin.getClassName();
 
 			String docs = jEdit.getProperty("plugin." + name + ".docs");
 			String label = jEdit.getProperty("plugin." + name + ".name");
-			if(label != null && docs != null)
+			if (label != null && docs != null)
 			{
-				String path = plugin.getPluginJAR()
-					.getClassLoader()
-					.getResourceAsPath(docs);
-				pluginTree.add(createNode(
-					path,label));
+				String path = plugin.getPluginJAR().getClassLoader().getResourceAsPath(docs);
+				pluginTree.add(createNode(path, label));
 			}
 		}
 
