@@ -41,7 +41,7 @@ import org.gjt.sp.util.StandardUtilities;
 /**
  * Abbrev editor.
  * @author Slava Pestov
- * @version $Id: AbbrevsOptionPane.java 21831 2012-06-18 22:54:17Z ezust $
+ * @version $Id: AbbrevsOptionPane.java 23920 2015-05-22 08:03:45Z ezust $
  */
 public class AbbrevsOptionPane extends AbstractOptionPane
 {
@@ -96,6 +96,7 @@ public class AbbrevsOptionPane extends AbstractOptionPane
 
 		globalAbbrevs = new AbbrevsModel(Abbrevs.getGlobalAbbrevs());
 		abbrevsTable = new JTable(globalAbbrevs);
+		abbrevsTable.setRowHeight(GUIUtilities.defaultRowHeight());
 		abbrevsTable.getColumnModel().getColumn(1).setCellRenderer(
 			new Renderer());
 		abbrevsTable.setAutoResizeMode(JTable.AUTO_RESIZE_ALL_COLUMNS);
@@ -385,14 +386,10 @@ public class AbbrevsOptionPane extends AbstractOptionPane
 		public Hashtable<String,String> toHashtable()
 		{
 			Hashtable<String,String> hash = new Hashtable<String,String>();
-			for(int i = 0; i < abbrevs.size(); i++)
+			for (Abbrev abbrev : abbrevs)
 			{
-				Abbrev abbrev = abbrevs.get(i);
-				if(abbrev.abbrev.length() > 0
-				   && abbrev.expand.length() > 0)
-				{
-					hash.put(abbrev.abbrev,abbrev.expand);
-				}
+				if (abbrev.abbrev.length() > 0 && abbrev.expand.length() > 0)
+					hash.put(abbrev.abbrev, abbrev.expand);
 			}
 			return hash;
 		} //}}}
