@@ -26,16 +26,22 @@ package org.gjt.sp.jedit.options;
 import javax.swing.*;
 
 import java.awt.event.*;
+import java.io.File;
+import java.io.IOException;
+import java.nio.file.*;
 import java.util.Arrays;
+import java.util.Objects;
 
 import org.gjt.sp.jedit.*;
 import org.gjt.sp.jedit.buffer.FoldHandler;
+import org.gjt.sp.jedit.gui.AddModeDialog;
+import org.gjt.sp.jedit.syntax.ModeProvider;
 import org.gjt.sp.util.StandardUtilities;
 //}}}
 
 /**
  * @author Slava Pestov
- * @version $Id: EditingOptionPane.java 21831 2012-06-18 22:54:17Z ezust $
+ * @version $Id: EditingOptionPane.java 24012 2015-08-12 08:48:07Z kpouer $
  */
 public class EditingOptionPane extends AbstractOptionPane
 {
@@ -49,21 +55,7 @@ public class EditingOptionPane extends AbstractOptionPane
 	@Override
 	protected void _init()
 	{
-		Mode[] modes = jEdit.getModes();
-		Arrays.sort(modes,new StandardUtilities.StringCompare<Mode>(true));
-
-		global = new ModeProperties();
-		modeProps = new ModeProperties[modes.length];
-
-		String[] modeNames = new String[modes.length + 1];
-		modeNames[0] = jEdit.getProperty("options.editing.global");
-
-		for(int i = 0; i < modes.length; i++)
-		{
-			modeProps[i] = new ModeProperties(modes[i]);
-			modeNames[i + 1] = modes[i].getName();
-		}
-
+		Mode[] modes = reloadModes();
 		mode = new JComboBox(modeNames);
 		mode.addActionListener(new ActionHandler());
 
@@ -72,6 +64,12 @@ public class EditingOptionPane extends AbstractOptionPane
 
 		addComponent(jEdit.getProperty("options.editing.mode"),mode);
 
+		deleteMode = new JButton(jEdit.getProperty("options.editing.deleteMode"));
+		deleteMode.setEnabled(false);
+		deleteMode.setVisible(false);
+		deleteMode.addActionListener(new ActionHandler());
+		addComponent(deleteMode);
+
 		useDefaults = new JCheckBox(jEdit.getProperty("options.editing.useDefaults"));
 		useDefaults.addActionListener(new ActionHandler());
 		addComponent(useDefaults);
@@ -140,7 +138,7 @@ public class EditingOptionPane extends AbstractOptionPane
 
 		addComponent(jEdit.getProperty("options.editing.firstlineGlob"),
 			firstlineGlob = new JTextField());
-
+		
 		selectMode();
 
 		addSeparator();
@@ -160,39 +158,33 @@ public class EditingOptionPane extends AbstractOptionPane
 		resetUndoOnSave.setSelected(jEdit.getBooleanProperty("resetUndoOnSave"));
 		addComponent(resetUndoOnSave);
 		//}}}
+		
+		addSeparator();
 
-		//{{{ Large file mode
-		addSeparator(jEdit.getProperty("options.editing.largefilemode.title"));
+		addMode = new JButton(jEdit.getProperty("options.editing.addMode"));
+		addMode.addActionListener(new ActionHandler());
+		addComponent(addMode);
 
-		addComponent(new JLabel(jEdit.getProperty("options.editing.largefilemode")));
-		addComponent(askLargeFileMode = new JRadioButton(jEdit.getProperty("options.editing.largefilemode.option.ask")));
-		addComponent(fullSyntaxLargeFileMode = new JRadioButton(jEdit.getProperty("options.editing.largefilemode.option.full")));
-		addComponent(limitedSyntaxLargeFileMode = new JRadioButton(jEdit.getProperty("options.editing.largefilemode.option.limited")));
-		addComponent(noHighlightLargeFileMode = new JRadioButton(jEdit.getProperty("options.editing.largefilemode.option.nohighlight")));
-		String option = jEdit.getProperty("largefilemode", "ask");
-		if ("full".equals(option))
-		{
-			fullSyntaxLargeFileMode.setSelected(true);
-		}
-		else if ("limited".equals(option))
-		{
-			limitedSyntaxLargeFileMode.setSelected(true);
-		}
-		else if ("nohighlight".equals(option))
-		{
-			noHighlightLargeFileMode.setSelected(true);
-		}
-		else
-		{
-			askLargeFileMode.setSelected(true);
-		}
-		ButtonGroup largeFileModeButtonGroup = new ButtonGroup();
-		largeFileModeButtonGroup.add(askLargeFileMode);
-		largeFileModeButtonGroup.add(fullSyntaxLargeFileMode);
-		largeFileModeButtonGroup.add(limitedSyntaxLargeFileMode);
-		largeFileModeButtonGroup.add(noHighlightLargeFileMode);
-		//}}}
 	} //}}}
+	
+	private Mode[] reloadModes()
+	{
+		Mode[] modes = jEdit.getModes();
+		Arrays.sort(modes,new StandardUtilities.StringCompare<Mode>(true));
+
+		global = new ModeProperties();
+		modeProps = new ModeProperties[modes.length];
+
+		modeNames = new String[modes.length + 1];
+		modeNames[0] = jEdit.getProperty("options.editing.global");
+
+		for(int i = 0; i < modes.length; i++)
+		{
+			modeProps[i] = new ModeProperties(modes[i]);
+			modeNames[i + 1] = modes[i].getName();
+		}
+		return modes;
+	}
 
 	//{{{ _save() method
 	@Override
@@ -207,26 +199,9 @@ public class EditingOptionPane extends AbstractOptionPane
 
 		global.save();
 
-		for(int i = 0; i < modeProps.length; i++)
+		for (ModeProperties modeProp : modeProps)
 		{
-			modeProps[i].save();
-		}
-
-		if (fullSyntaxLargeFileMode.isSelected())
-		{
-			jEdit.setProperty("largefilemode", "full");
-		}
-		else if (limitedSyntaxLargeFileMode.isSelected())
-		{
-			jEdit.setProperty("largefilemode", "limited");
-		}
-		else if (noHighlightLargeFileMode.isSelected())
-		{
-			jEdit.setProperty("largefilemode", "nohighlight");
-		}
-		else
-		{
-			jEdit.setProperty("largefilemode", "ask");
+			modeProp.save();
 		}
 	} //}}}
 
@@ -244,6 +219,8 @@ public class EditingOptionPane extends AbstractOptionPane
 	private JCheckBox useDefaults;
 	private JTextField filenameGlob;
 	private JTextField firstlineGlob;
+	private JButton deleteMode;
+	private JButton addMode;
 	private JTextField noWordSep;
 	private JCheckBox camelCasedWords;
 	private JComboBox folding;
@@ -256,11 +233,7 @@ public class EditingOptionPane extends AbstractOptionPane
 	private JCheckBox elasticTabstops;
 	private JComboBox autoIndent;
 	private JCheckBox deepIndent;
-	private JRadioButton largeFileMode;
-	private JRadioButton askLargeFileMode;
-	private JRadioButton noHighlightLargeFileMode;
-	private JRadioButton limitedSyntaxLargeFileMode;
-	private JRadioButton fullSyntaxLargeFileMode;
+	private String[] modeNames;
 	//}}}
 
 	//{{{ saveMode() method
@@ -286,7 +259,7 @@ public class EditingOptionPane extends AbstractOptionPane
 	//{{{ selectMode() method
 	private void selectMode()
 	{
-		int index = mode.getSelectedIndex();
+		int index = mode.getSelectedIndex() < 0 ? 0 : mode.getSelectedIndex();
 		current = index == 0 ? global : modeProps[index - 1];
 		current.edited = true;
 		current.load();
@@ -311,6 +284,8 @@ public class EditingOptionPane extends AbstractOptionPane
 		elasticTabstops.setSelected(current.elasticTabstops);
 		autoIndent.setSelectedItem(current.autoIndent);
 		deepIndent.setSelected(current.deepIndent);
+		deleteMode.setEnabled(current.isUserMode);
+		deleteMode.setVisible(current.isUserMode);
 
 		updateEnabled();
 		revalidate();
@@ -369,6 +344,64 @@ public class EditingOptionPane extends AbstractOptionPane
 					useDefaults.isSelected();
 				updateEnabled();
 			}
+			else if (source == deleteMode)
+			{
+				int answer = JOptionPane.showConfirmDialog(EditingOptionPane.this, jEdit.getProperty("options.editing.deleteMode.dialog.message"), jEdit.getProperty("options.editing.deleteMode.dialog.title"), JOptionPane.YES_NO_OPTION);
+				if (JOptionPane.YES_OPTION == answer && current.mode != null)
+				{
+					String modeName = current.mode.getName();
+					try
+					{
+						ModeProvider.instance.removeMode(modeName);
+					}
+					catch (IOException e)
+					{
+						Mode mode = ModeProvider.instance.getMode(modeName);
+						JOptionPane.showMessageDialog(jEdit.getActiveView(),
+								jEdit.getProperty("options.editing.deleteMode.dialog.message1") + ' ' + mode.getProperty("file") +
+										'\n' + jEdit.getProperty("options.editing.deleteMode.dialog.message2") + ' ' + EditingOptionPane.this.mode.getName());
+					}
+					mode.removeItem(modeName);
+				}
+			}
+			else if (source == addMode)
+			{
+				AddModeDialog dialog = new AddModeDialog(jEdit.getActiveView());
+				if (dialog.isCanceled())
+					return;
+				String modeName = dialog.getModeName();
+				boolean exists = jEdit.getMode(modeName) != null;
+				if (exists)
+				{
+					int answer = JOptionPane.showConfirmDialog(EditingOptionPane.this, jEdit.getProperty("options.editing.addMode.dialog.warning.message"), jEdit.getProperty("options.editing.addMode.dialog.warning.title") + " " + modeName, JOptionPane.YES_NO_OPTION);
+					if (JOptionPane.YES_OPTION != answer)
+						return;
+				}
+				
+				// create mode and set properties from dialog values
+				Mode newMode = new Mode(modeName);
+				String modeFile = dialog.getModeFile();
+				newMode.setProperty("file", modeFile);
+				newMode.setProperty("filenameGlob", dialog.getFilenameGlob());
+				newMode.setProperty("firstlineGlob", dialog.getFirstLineGlob());
+
+				File file = new File(modeFile);
+				Path target = FileSystems.getDefault().getPath(jEdit.getSettingsDirectory(), "modes", file.getName());
+				try
+				{
+					ModeProvider.instance.addUserMode(newMode, target);
+				}
+				catch (IOException e)
+				{
+					JOptionPane.showMessageDialog(jEdit.getActiveView(), jEdit.getProperty("options.editing.addMode.dialog.warning.message1") + " " + modeFile + "\n--> " + target);
+				}
+
+				// refresh the mode dropdown so the new mode is in the list
+				jEdit.reloadModes();
+				reloadModes();
+				mode.setModel(new DefaultComboBoxModel(modeNames));
+				mode.setSelectedItem(modeName);
+			}
 		}
 	} //}}}
 
@@ -395,6 +428,7 @@ public class EditingOptionPane extends AbstractOptionPane
 		boolean elasticTabstops;
 		String autoIndent;
 		boolean deepIndent;
+		boolean isUserMode;
 		//}}}
 
 		//{{{ ModeProperties constructor
@@ -436,6 +470,7 @@ public class EditingOptionPane extends AbstractOptionPane
 				elasticTabstops = mode.getBooleanProperty("elasticTabstops");
 				autoIndent = mode.getProperty("autoIndent").toString();
 				deepIndent = mode.getBooleanProperty("deepIndent");
+				isUserMode = mode.isUserMode();
 			}
 			else
 			{
@@ -489,10 +524,8 @@ public class EditingOptionPane extends AbstractOptionPane
 					jEdit.resetProperty(prefix + "autoIndent");
 					jEdit.resetProperty(prefix + "deepIndent");
 
-					if(!(StandardUtilities.objectsEqual(oldFilenameGlob,
-						mode.getProperty("filenameGlob"))
-						&& StandardUtilities.objectsEqual(oldFirstlineGlob,
-						mode.getProperty("firstlineGlob"))))
+					if(!(Objects.equals(oldFilenameGlob, mode.getProperty("filenameGlob"))
+						&& Objects.equals(oldFirstlineGlob, mode.getProperty("firstlineGlob"))))
 					{
 						mode.init();
 					}
@@ -504,10 +537,8 @@ public class EditingOptionPane extends AbstractOptionPane
 					jEdit.setProperty(prefix + "filenameGlob",filenameGlob);
 					jEdit.setProperty(prefix + "firstlineGlob",firstlineGlob);
 
-					if(!(StandardUtilities.objectsEqual(oldFilenameGlob,
-						filenameGlob)
-						&& StandardUtilities.objectsEqual(oldFirstlineGlob,
-						firstlineGlob)))
+					if(!(Objects.equals(oldFilenameGlob, filenameGlob) &&
+						 Objects.equals(oldFirstlineGlob, firstlineGlob)))
 					{
 						mode.init();
 					}
