@@ -49,7 +49,7 @@ import java.util.List;
 /**
  * Key binding editor.
  * @author Slava Pestov
- * @version $Id: ShortcutsOptionPane.java 23082 2013-07-27 16:01:18Z ezust $
+ * @version $Id: ShortcutsOptionPane.java 23920 2015-05-22 08:03:45Z ezust $
  */
 @SuppressWarnings("serial")
 public class ShortcutsOptionPane extends AbstractOptionPane
@@ -64,7 +64,7 @@ public class ShortcutsOptionPane extends AbstractOptionPane
 	@Override
 	protected void _init()
 	{
-		allBindings = new Vector<KeyBinding>();
+		allBindings = new Vector<>();
 
 		setLayout(new BorderLayout(12, 12));
 
@@ -83,8 +83,8 @@ public class ShortcutsOptionPane extends AbstractOptionPane
 
 		ActionListener actionHandler = new ActionHandler();
 
-		ComboBoxModel model = new KeymapsModel();
-		keymaps = new JComboBox(model);
+		ComboBoxModel<String> model = new KeymapsModel();
+		keymaps = new JComboBox<>(model);
 		keymaps.setRenderer(new KeymapCellRenderer());
 		keymaps.setSelectedItem(keymapName);
 		duplicateKeymap.addActionListener(actionHandler);
@@ -93,19 +93,17 @@ public class ShortcutsOptionPane extends AbstractOptionPane
 		keymaps.addActionListener(actionHandler);
 		keymaps.setSelectedItem(selectedKeymap);
 
-		Box keymapBox = Box.createHorizontalBox();
+		JPanel keymapBox = new JPanel(new FlowLayout(FlowLayout.LEADING));
 		keymapBox.add(new JLabel(jEdit.getProperty(
 			"options.shortcuts.keymap.label")));
-		keymapBox.add(Box.createHorizontalStrut(6));
 		keymapBox.add(keymaps);
 		keymapBox.add(Box.createHorizontalStrut(6));
 		keymapBox.add(duplicateKeymap);
 		keymapBox.add(resetKeymap);
 		keymapBox.add(deleteKeymap);
-		keymapBox.add(Box.createHorizontalGlue());
 
 		// combobox to choose action set
-		selectModel = new JComboBox(models);
+		selectModel = new JComboBox<>(models);
 		selectModel.addActionListener(actionHandler);
 		selectModel.setToolTipText(jEdit.getProperty("options.shortcuts.select.tooltip"));
 		Box north = Box.createHorizontalBox();
@@ -155,6 +153,7 @@ public class ShortcutsOptionPane extends AbstractOptionPane
 
 		keyTable = new JTable(filteredModel);
 		filteredModel.setTable(keyTable);
+		keyTable.setRowHeight(GUIUtilities.defaultRowHeight());
 		keyTable.getTableHeader().setReorderingAllowed(false);
 		keyTable.getTableHeader().addMouseListener(new HeaderMouseHandler());
 		keyTable.addMouseListener(new TableMouseHandler());
@@ -201,11 +200,11 @@ public class ShortcutsOptionPane extends AbstractOptionPane
 	private JButton duplicateKeymap;
 	private JButton resetKeymap;
 	private JButton deleteKeymap;
-	private JComboBox keymaps;
+	private JComboBox<String> keymaps;
 	private JTable keyTable;
 	private Vector<ShortcutsModel> models;
 	private FilteredTableModel<ShortcutsModel> filteredModel;
-	private JComboBox selectModel;
+	private JComboBox<ShortcutsModel> selectModel;
 	private List<KeyBinding> allBindings;
 	private JTextField filterTF;
 
@@ -233,7 +232,7 @@ public class ShortcutsOptionPane extends AbstractOptionPane
 				return name.contains(filter);
 			}
 		};
-		models = new Vector<ShortcutsModel>();
+		models = new Vector<>();
 		reloadModels();
 	} //}}}
 
@@ -242,22 +241,20 @@ public class ShortcutsOptionPane extends AbstractOptionPane
 	{
 		models.clear();
 		allBindings.clear();
-		List<KeyBinding[]> allBindings = new ArrayList<KeyBinding[]>();
-		Collection<String> knownBindings = new HashSet<String>();
+		List<KeyBinding[]> allBindings = new ArrayList<>();
+		Collection<String> knownBindings = new HashSet<>();
 		ActionSet[] actionSets = jEdit.getActionSets();
-		for(int i = 0; i < actionSets.length; i++)
+		for (ActionSet actionSet : actionSets)
 		{
-			ActionSet actionSet = actionSets[i];
-			if(actionSet.getActionCount() != 0)
+			if (actionSet.getActionCount() != 0)
 			{
 				String modelLabel = actionSet.getLabel();
-				if(modelLabel == null)
+				if (modelLabel == null)
 				{
-					Log.log(Log.ERROR,this,"Empty action set: "
-						+ actionSet.getPluginJAR());
+					Log.log(Log.ERROR, this, "Empty action set: " + actionSet.getPluginJAR());
 				}
-				ShortcutsModel model = createModel(actionSet.getLabel(), modelLabel,
-						actionSet.getActionNames());
+				ShortcutsModel model =
+					createModel(actionSet.getLabel(), modelLabel, actionSet.getActionNames());
 				models.add(model);
 				List<KeyBinding[]> bindings = model.getBindings();
 				for (KeyBinding[] binding : bindings)
@@ -298,19 +295,18 @@ public class ShortcutsOptionPane extends AbstractOptionPane
 	//{{{ createModel() method
 	private ShortcutsModel createModel(String actionSet, String modelLabel, String[] actions)
 	{
-		List<GrabKeyDialog.KeyBinding[]> bindings = new ArrayList<GrabKeyDialog.KeyBinding[]>(actions.length);
+		List<KeyBinding[]> bindings = new ArrayList<>(actions.length);
 
-		for(int i = 0; i < actions.length; i++)
+		for (String name : actions)
 		{
-			String name = actions[i];
 			EditAction ea = jEdit.getAction(name);
 			String label = ea.getLabel();
 			// Skip certain actions this way
-			if(label == null)
+			if (label == null)
 				continue;
 
 			label = GUIUtilities.prettifyMenuLabel(label);
-			addBindings(actionSet, name,label,bindings);
+			addBindings(actionSet, name, label, bindings);
 		}
 
 		return new ShortcutsModel(modelLabel,bindings);
@@ -319,7 +315,7 @@ public class ShortcutsOptionPane extends AbstractOptionPane
 	//{{{ addBindings() method
 	private void addBindings(String actionSet, String name, String label, Collection<KeyBinding[]> bindings)
 	{
-		GrabKeyDialog.KeyBinding[] b = new GrabKeyDialog.KeyBinding[2];
+		KeyBinding[] b = new KeyBinding[2];
 
 		b[0] = createBinding(actionSet, name,label,
 			selectedKeymap.getShortcut(name + ".shortcut"));
@@ -330,13 +326,12 @@ public class ShortcutsOptionPane extends AbstractOptionPane
 	} //}}}
 
 	//{{{ createBinding() method
-	private GrabKeyDialog.KeyBinding createBinding(String actionSet, String name, String label, String shortcut)
+	private KeyBinding createBinding(String actionSet, String name, String label, String shortcut)
 	{
-		if(shortcut != null && shortcut.length() == 0)
+		if(shortcut != null && shortcut.isEmpty())
 			shortcut = null;
 
-		GrabKeyDialog.KeyBinding binding
-			= new GrabKeyDialog.KeyBinding(name,label,shortcut,false);
+		KeyBinding binding = new KeyBinding(name,label,shortcut,false);
 
 		binding.actionSet = actionSet;
 		allBindings.add(binding);
@@ -432,7 +427,7 @@ public class ShortcutsOptionPane extends AbstractOptionPane
 										     "options.shortcuts.duplicatekeymap.dialog.label"),
 									     jEdit.getProperty(
 										     "options.shortcuts.duplicatekeymap.dialog.title"),
-									     JOptionPane.OK_CANCEL_OPTION);
+									     JOptionPane.QUESTION_MESSAGE);
 				if (newName == null)
 				{
 					return;
@@ -440,16 +435,14 @@ public class ShortcutsOptionPane extends AbstractOptionPane
 				newName = newName.replace(' ', '_');
 				KeymapManager manager = jEdit.getKeymapManager();
 				Collection<String> keymapNames = manager.getKeymapNames();
-				while (newName != null)
+				while (keymapNames.contains(newName))
 				{
-					if (!keymapNames.contains(newName))
-						break;
 					newName = JOptionPane.showInputDialog(ShortcutsOptionPane.this,
 										     jEdit.getProperty(
 											     "options.shortcuts.duplicatekeymap.keymapalreadyexists.label"),
 										     jEdit.getProperty(
 											     "options.shortcuts.duplicatekeymap.dialog.title"),
-										     JOptionPane.OK_CANCEL_OPTION);
+										     JOptionPane.QUESTION_MESSAGE);
 					if (newName == null)
 					{
 						return;
@@ -504,17 +497,17 @@ public class ShortcutsOptionPane extends AbstractOptionPane
 	private class ShortcutsModel extends AbstractTableModel
 	{
 		public static final String ALL = "All";
-		private final List<GrabKeyDialog.KeyBinding[]> bindings;
+		private final List<KeyBinding[]> bindings;
 		private final String name;
 
-		ShortcutsModel(String name, List<GrabKeyDialog.KeyBinding[]> bindings)
+		ShortcutsModel(String name, List<KeyBinding[]> bindings)
 		{
 			this.name = name;
 			this.bindings = bindings;
 			sort(0);
 		}
 
-		public List<GrabKeyDialog.KeyBinding[]> getBindings()
+		public List<KeyBinding[]> getBindings()
 		{
 			return bindings;
 		}
@@ -543,16 +536,18 @@ public class ShortcutsOptionPane extends AbstractOptionPane
 		{
 			// The only place this gets used is in JTable's own display code, so
 			// we translate the shortcut to platform-specific form for display here.
+			KeyBinding bindingAt = getBindingAt(row, 0);
+			setToolTipText(bindingAt.label);
 			switch(col)
 			{
 			case 0:
-				return getBindingAt(row,0).label;
+				return bindingAt.label;
 			case 1:
-				return GUIUtilities.getPlatformShortcutLabel(getBindingAt(row,0).shortcut);
+				return GUIUtilities.getPlatformShortcutLabel(bindingAt.shortcut);
 			case 2:
 				return GUIUtilities.getPlatformShortcutLabel(getBindingAt(row,1).shortcut);
 			case 3:
-				return getBindingAt(row, 0).actionSet;
+				return bindingAt.actionSet;
 			default:
 				return null;
 			}
@@ -591,7 +586,7 @@ public class ShortcutsOptionPane extends AbstractOptionPane
 
 		public void save()
 		{
-			for (GrabKeyDialog.KeyBinding[] binding : bindings)
+			for (KeyBinding[] binding : bindings)
 			{
 				selectedKeymap.setShortcut(
 					binding[0].name + ".shortcut",
@@ -602,9 +597,9 @@ public class ShortcutsOptionPane extends AbstractOptionPane
 			}
 		}
 
-		public GrabKeyDialog.KeyBinding getBindingAt(int row, int nr)
+		public KeyBinding getBindingAt(int row, int nr)
 		{
-			GrabKeyDialog.KeyBinding[] binding = bindings.get(row);
+			KeyBinding[] binding = bindings.get(row);
 			return binding[nr];
 		}
 
@@ -614,7 +609,7 @@ public class ShortcutsOptionPane extends AbstractOptionPane
 			return name;
 		}
 
-		private class KeyCompare implements Comparator<GrabKeyDialog.KeyBinding[]>
+		private class KeyCompare implements Comparator<KeyBinding[]>
 		{
 			private final int col;
 
@@ -624,7 +619,7 @@ public class ShortcutsOptionPane extends AbstractOptionPane
 			}
 
 			@Override
-			public int compare(GrabKeyDialog.KeyBinding[] k1, GrabKeyDialog.KeyBinding[] k2)
+			public int compare(KeyBinding[] k1, KeyBinding[] k2)
 			{
 				String label1 = k1[0].label.toLowerCase();
 				String label2 = k2[0].label.toLowerCase();
@@ -660,7 +655,7 @@ public class ShortcutsOptionPane extends AbstractOptionPane
 	} //}}}
 
 	//{{{ KeymapsModel class
-	private static class KeymapsModel extends AbstractListModel implements ComboBoxModel
+	private static class KeymapsModel extends AbstractListModel<String> implements ComboBoxModel<String>
 	{
 		private String[] keymaps;
 
@@ -692,7 +687,7 @@ public class ShortcutsOptionPane extends AbstractOptionPane
 
 		//{{{ getElementAt() method
 		@Override
-		public Object getElementAt(int index)
+		public String getElementAt(int index)
 		{
 			return keymaps[index];
 		} //}}}
@@ -730,7 +725,7 @@ public class ShortcutsOptionPane extends AbstractOptionPane
 	private static class KeymapCellRenderer extends DefaultListCellRenderer
 	{
 		@Override
-		public Component getListCellRendererComponent(JList list, Object value, int index,
+		public Component getListCellRendererComponent(JList<?> list, Object value, int index,
 							      boolean isSelected, boolean cellHasFocus)
 		{
 			super.getListCellRendererComponent(list, value, index, isSelected,
