@@ -3,7 +3,8 @@
  * :tabSize=4:indentSize=4:noTabs=false:
  * :folding=explicit:collapseFolds=1:
  *
- * Copyright (C) 2002 Kris Kopicki
+ * Copyright (C) 2002-2013 Kris Kopicki, Slava Pestov, Dale Anson,
+ *      Matthieu Casanova, Alan Ezust, Björn "Vampire" Kautler
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -30,7 +31,7 @@ import org.gjt.sp.jedit.io.VFS;
 import org.gjt.sp.jedit.io.VFSManager;
 import org.gjt.sp.util.Log;
 import org.gjt.sp.util.StandardUtilities;
-import org.gjt.sp.util.ThreadUtilities;
+import org.gjt.sp.util.StringList;
 import org.gjt.sp.util.XMLUtilities;
 import org.xml.sax.Attributes;
 import org.xml.sax.SAXException;
@@ -52,6 +53,7 @@ import java.awt.*;
 import java.awt.event.*;
 import java.io.File;
 import java.io.InputStream;
+import java.text.MessageFormat;
 import java.text.NumberFormat;
 import java.text.ParseException;
 import java.text.SimpleDateFormat;
@@ -60,7 +62,7 @@ import java.util.List;
 //}}}
 
 /**
- * @version $Id: InstallPanel.java 22967 2013-05-06 09:15:44Z kpouer $
+ * @version $Id: InstallPanel.java 24084 2015-09-17 18:44:47Z kerik-sf $
  */
 class InstallPanel extends JPanel implements EBComponent
 {
@@ -74,6 +76,9 @@ class InstallPanel extends JPanel implements EBComponent
 	private final ChoosePluginSet chooseButton;
 	private final boolean updates;
 	private final CardLayout layout;
+	private final JTextField searchField;
+	private boolean hideInstalled;
+	private boolean isLoading;
 
 	private final Collection<String> pluginSet = new HashSet<String>();
 	//}}}
@@ -95,7 +100,7 @@ class InstallPanel extends JPanel implements EBComponent
 		table = new JTable(pluginModel = new PluginTableModel());
 		table.setShowGrid(false);
 		table.setIntercellSpacing(new Dimension(0,0));
-		table.setRowHeight(table.getRowHeight() + 2);
+		table.setRowHeight(GUIUtilities.defaultRowHeight() + 2);
 		table.setPreferredScrollableViewportSize(new Dimension(500,200));
 		table.setDefaultRenderer(Object.class, new TextRenderer(
 			(DefaultTableCellRenderer)table.getDefaultRenderer(Object.class)));
@@ -152,7 +157,7 @@ class InstallPanel extends JPanel implements EBComponent
 			}
 		});
 
-		final JTextField searchField = new JTextField();
+		searchField = new JTextField();
 		searchField.addKeyListener(new KeyAdapter()
 		{
 			@Override
@@ -196,17 +201,48 @@ class InstallPanel extends JPanel implements EBComponent
 			public void keyPressed(KeyEvent e)
 			{
 				int i = table.getSelectedRow(), n = table.getModel().getRowCount();
-				if (e.getKeyCode() == KeyEvent.VK_DOWN && i == (n - 1) ||
+				if (e.getKeyChar() == '/' ||
+					e.getKeyCode() == KeyEvent.VK_DOWN && i == (n - 1) ||
 					e.getKeyCode() == KeyEvent.VK_UP && i == 0) 
 				{
 					searchField.requestFocus();
 					searchField.selectAll();
 				}
 			}
+			@Override
+			public void keyTyped(KeyEvent e)
+			{
+				char c = e.getKeyChar();
+				if(c != KeyEvent.CHAR_UNDEFINED && Character.isAlphabetic(c))
+				{
+					searchField.dispatchEvent(e);
+					searchField.requestFocus();
+				}
+			}
 		});
+		hideInstalled = !updates;
+		final JCheckBox hideInstalledCB = new JCheckBox("Hide installed plugins", hideInstalled);
+		hideInstalledCB.addActionListener(new ActionListener()
+		{
+
+			@Override
+			public void actionPerformed(ActionEvent e)
+			{
+				InstallPanel.this.hideInstalled = hideInstalledCB.isSelected();
+				updateModel();
+			}
+		});
+		hideInstalledCB.setAlignmentX(0);
+
 		Box filterBox = Box.createHorizontalBox();
 		filterBox.add(new JLabel("Filter : "));
 		filterBox.add(searchField);
+		filterBox.setAlignmentX(0);
+		Box topBox = new Box(BoxLayout.PAGE_AXIS);
+		topBox.add(filterBox);
+		if(!updates){
+			topBox.add(hideInstalledCB);
+		}
 
 		/* Create buttons */
 		Box buttons = new Box(BoxLayout.X_AXIS);
@@ -220,7 +256,7 @@ class InstallPanel extends JPanel implements EBComponent
 		buttons.add(new SizeLabel());
 
 		JPanel _installPanel = new JPanel(new BorderLayout(12, 12));
-		_installPanel.add(BorderLayout.NORTH,filterBox);
+		_installPanel.add(BorderLayout.NORTH,topBox);
 		_installPanel.add(BorderLayout.CENTER,split);
 		_installPanel.add(BorderLayout.SOUTH, buttons);
 
@@ -260,7 +296,7 @@ class InstallPanel extends JPanel implements EBComponent
 	boolean loadPluginSet(String path)
 	{
 		pluginSet.clear();
-		pluginModel.restoreSelection(new HashSet<String>(), new HashSet<String>());
+		pluginModel.clearSelection();
 
 		VFS vfs = VFSManager.getVFSForPath(path);
 		Object session = vfs.createVFSSession(path, InstallPanel.this);
@@ -279,33 +315,32 @@ class InstallPanel extends JPanel implements EBComponent
 	} //}}}
 
 	//{{{ updateModel() method
+	/**
+	 * Must be called from the EDT.
+	 **/
 	public void updateModel()
 	{
-		final Set<String> savedChecked = new HashSet<String>();
-		final Set<String> savedSelection = new HashSet<String>();
-		pluginModel.saveSelection(savedChecked, savedSelection);
-		pluginModel.clear();
-		infoBox.setText(jEdit.getProperty("plugin-manager.list-download"));
-
-		ThreadUtilities.runInDispatchThread(new Runnable()
+		infoBox.setText(null);
+		pluginModel.update();
+		if (pluginModel.getRowCount() == 0)
 		{
-			@Override
-			public void run()
+			if (updates)
+				layout.show(InstallPanel.this, "PLUGIN_ARE_UP_TO_DATE");
+			else
+				layout.show(InstallPanel.this, "NO_PLUGIN_AVAILABLE");
+		}
+		else
+		{
+			layout.show(InstallPanel.this, "INSTALL");
+			EventQueue.invokeLater(new Runnable()
 			{
-				infoBox.setText(null);
-				pluginModel.update();
-				pluginModel.restoreSelection(savedChecked, savedSelection);
-				if (pluginModel.getRowCount() == 0)
+				public void run()
 				{
-					if (updates)
-						layout.show(InstallPanel.this, "PLUGIN_ARE_UP_TO_DATE");
-					else
-						layout.show(InstallPanel.this, "NO_PLUGIN_AVAILABLE");
+					searchField.requestFocusInWindow();
 				}
-				else
-					layout.show(InstallPanel.this, "INSTALL");
-			}
-		});
+			});
+		}
+		isLoading = false;
 	} //}}}
 
 	//{{{ handleMessage() method
@@ -318,7 +353,7 @@ class InstallPanel extends JPanel implements EBComponent
 			 if (chooseButton.path.length() > 0)
 			 {
 				 loadPluginSet(chooseButton.path);
-				 pluginModel.restoreSelection(new HashSet<String>(), new HashSet<String>());
+				 pluginModel.clearSelection();
 				 chooseButton.updateUI();
 			 }
 		}
@@ -328,10 +363,18 @@ class InstallPanel extends JPanel implements EBComponent
 	void loading()
 	{
 		layout.show(this, "LOADING");
+		isLoading = true;
 	} //}}}
 
 	//{{{ Private members
 
+	//{{{ isDownloadingList() method
+	private boolean isDownloadingList()
+	{
+		return isLoading;
+	} //}}}
+
+
 	//{{{ formatSize() method
 	private static String formatSize(int size)
 	{
@@ -353,9 +396,8 @@ class InstallPanel extends JPanel implements EBComponent
 	//{{{ PluginTableModel class
 	private class PluginTableModel extends AbstractTableModel
 	{
-		/** This List can contain String or Entry. */
-		private final List entries = new ArrayList();
-		private final List filteredEntries = new ArrayList();
+		private final List<Entry> entries = new ArrayList<Entry>();
+		private final List<Entry> filteredEntries = new ArrayList<Entry>();
 		private int sortType = EntryCompare.COLUMN_NAME;
 		private String filterString;
 		int sortDirection = 1;
@@ -372,22 +414,37 @@ class InstallPanel extends JPanel implements EBComponent
 		{
 			filteredEntries.clear();
 			if (filterString == null)
-				filteredEntries.addAll(entries);
+			{
+				if(!hideInstalled)
+				{
+					filteredEntries.addAll(entries);
+				}
+				else
+				{
+					for(Entry e: entries)
+					{
+						if(e.install || e.installedVersion == null || updates)
+						{
+							filteredEntries.add(e);
+						}
+					}
+				}
+			}
 			else
 			{
 				String[] words = filterString.toLowerCase().split("\\s+");
-				for (Object o : entries)
+				for (Entry e : entries)
 				{
-					if (!(o instanceof Entry))
-						continue;
-					Entry e = (Entry)o;
-
 					if (e.install)
 					{
 						filteredEntries.add(e);
 						continue;
 					}
 
+					if(hideInstalled && e.installedVersion != null)
+					{
+						continue;
+					}
 					
 					String s = (e.name + ' ' + e.set + ' ' + e.description).toLowerCase();
 					boolean hasAll = true;
@@ -487,7 +544,7 @@ class InstallPanel extends JPanel implements EBComponent
 					case 2:
 						return entry.set;
 					case 3:
-						if (updates)
+						if (entry.installedVersion != null)
 							return entry.installedVersion + "->" + entry.version;
 						return entry.version;
 					case 4:
@@ -521,7 +578,7 @@ class InstallPanel extends JPanel implements EBComponent
 				else
 				{
 					Entry entry = (Entry)filteredEntries.get(i);
-					entry.parents = new LinkedList<Entry>();
+					entry.dependents = new LinkedList<Entry>();
 					entry.install = false;
 				}
 			}
@@ -535,28 +592,40 @@ class InstallPanel extends JPanel implements EBComponent
 			sort(type);
 		} //}}}
 
-		//{{{ deselectParents() method
-		private void deselectParents(Entry entry)
+		//{{{ deselectDependents() method
+		/**
+		 * deselect all plugins depending upon entry after a warning.
+		 * If user cancels, reinstate install field of entry
+		 * @param entry	the entry that would be no more installed
+		 * @return	confirmed that deselection may proceed
+		 */
+		private boolean deselectDependents(Entry entry)
 		{
-			Entry[] parents = entry.getParents();
+			Entry[] dependents = entry.getTransitiveDependents();
 
-			if (parents.length == 0)
-				return;
+			if (dependents.length == 0)
+				return true;
 
 			String[] args = { entry.name };
 			int result = GUIUtilities.listConfirm(
 				window,"plugin-manager.dependency",
-				args,parents);
+				args,dependents);
 			if (result != JOptionPane.OK_OPTION)
 			{
 				entry.install = true;
-				return;
+				return false;
 			}
 
-			for(int i = 0; i < parents.length; i++)
-				 parents[i].install = false;
-
-			fireTableRowsUpdated(0,getRowCount() - 1);
+			for(Entry dependent: dependents)
+			{
+				 dependent.install = false;
+				 dependent.checked = false;
+				 // must setInstall() to remove the
+				 // plugin from its dependencies 'dependents' list
+				 // so that they can be unchecked if no longer required
+				 updateDeps(dependent);
+			}
+			return true;
 		} //}}}
 
 		//{{{ setValueAt() method
@@ -565,66 +634,109 @@ class InstallPanel extends JPanel implements EBComponent
 		{
 			if (column != 0) return;
 
-			Object obj = filteredEntries.get(row);
-			if(obj instanceof String)
-				return;
+			Entry entry = filteredEntries.get(row);
 
-			Entry entry = (Entry)obj;
 			boolean before = entry.install;
 			entry.install = Boolean.TRUE.equals(aValue);
 			if (before == entry.install) return;
-			if (!entry.install)
-				deselectParents(entry);
+
+			// deselect after a warning if entry is required
+			// by some other selected plugin.
+			// If the user cancelled, don't proceed
+			if (!entry.install && !deselectDependents(entry))
+			{
+				return;
+			}
+
+			// checked is set after deselectDependents to prevent
+			// override when the user cancelled deselectDependents
+			entry.checked = entry.install;
+
+			updateDeps(entry);
+
+			/* prune entries to install to keep only the entries
+			 * really checked by the user.
+			 * Removes dependencies no longer required and such */
+
+			List<Entry> selected = new ArrayList<Entry>(entries.size());
+			for(Entry temp: entries)
+			{
+				if(temp.install)selected.add(temp);
+			}
+
+			List<Entry> toRemove = new ArrayList<Entry>(selected.size());
+			boolean changed;
+			do{
+				changed = false;
+				for(Entry temp: selected)
+				{
+					temp.dependents.removeAll(toRemove);
+					if(!temp.checked && temp.dependents.isEmpty())
+					{
+						toRemove.add(temp);
+						temp.install = false;
+						changed = true;
+					}
+				}
+				selected.removeAll(toRemove);
+			}while(changed);
+
+			updateFilteredEntries();
+			// make the row selected after updated filtering
+			for(int i=0; i< filteredEntries.size(); i++)
+			{
+				if(entry == filteredEntries.get(i))
+				{
+					table.setRowSelectionInterval(i, i);
+					break;
+				}
+			}
+		} //}}}
+
+		//{{{ updateDeps() method
+		/***
+		 * recursively add dependencies to install,
+		 * or remove entry from its dependencies' dependents list
+		 * @param entry	entry whose install field has been set
+		 */
+		private void updateDeps(Entry entry)
+		{
 
 			List<PluginList.Dependency> deps = entry.plugin.getCompatibleBranch().deps;
 
-			for (int i = 0; i < deps.size(); i++)
+			for (PluginList.Dependency dep: deps)
 			{
-				PluginList.Dependency dep = deps.get(i);
 				if ("plugin".equals(dep.what))
 				{
-					boolean found = false;
-					for (int j = 0; j < filteredEntries.size(); j++)
+					for (Entry temp: entries)
 					{
-						Entry temp = (Entry)filteredEntries.get(j);
 						if (temp.plugin == dep.plugin)
 						{
-							found = true;
 							if (entry.install)
 							{
-								temp.parents.add(entry);
-								setValueAt(Boolean.TRUE,j,0);
+								temp.dependents.add(entry);
+								if(!temp.install)
+								{
+									if(temp.installedVersion == null)
+									{
+										temp.install = true;
+									}
+									else if(!temp.plugin.loaded)
+									{
+										temp.install = true;
+									}
+									updateDeps(temp);
+								}
 							}
 							else
-								temp.parents.remove(entry);
-
-							break;
-						}
-					}
-					if (!found)
-					{
-						// the dependency was not found in the filtered list so we search in
-						// global list.
-						for (int a = 0;a<entries.size();a++)
-						{
-							Entry temp = (Entry) entries.get(a);
-							if (temp.plugin == dep.plugin)
 							{
-								if (entry.install)
-								{
-									temp.parents.add(entry);
-									temp.install = true;
-								}
-								else
-									temp.parents.remove(entry);
-								break;
+								temp.dependents.remove(entry);
 							}
+							break;
 						}
 					}
 				}
 			}
-			updateFilteredEntries();
-			table.setRowSelectionInterval(row, row);
 		} //}}}
 
 		//{{{ sort() method
@@ -640,9 +752,6 @@ class InstallPanel extends JPanel implements EBComponent
 			}
 			sortType = type;
 
-			if(isDownloadingList())
-				return;
-
 			Collections.sort(entries,new EntryCompare(type, sortDirection));
 			updateFilteredEntries();
 			restoreSelection(savedChecked,savedSelection);
@@ -650,19 +759,6 @@ class InstallPanel extends JPanel implements EBComponent
 		}
 		//}}}
 
-		//{{{ isDownloadingList() method
-		private boolean isDownloadingList()
-		{
-			return entries.size() == 1 && entries.get(0) instanceof String;
-		} //}}}
-
-		//{{{ clear() method
-		public void clear()
-		{
-			entries.clear();
-			updateFilteredEntries();
-		} //}}}
-
 		//{{{ update() method
 		public void update()
 		{
@@ -676,9 +772,8 @@ class InstallPanel extends JPanel implements EBComponent
 
 			entries.clear();
 			
-			for(int i = 0; i < pluginList.pluginSets.size(); i++)
+			for(PluginList.PluginSet set : pluginList.pluginSets)
 			{
-				PluginList.PluginSet set = pluginList.pluginSets.get(i);
 				for(int j = 0; j < set.plugins.size(); j++)
 				{
 					PluginList.Plugin plugin = pluginList.pluginHash.get(set.plugins.get(j));
@@ -698,14 +793,13 @@ class InstallPanel extends JPanel implements EBComponent
 					}
 					else
 					{
-						if(installedVersion == null && plugin.canBeInstalled())
+						if(plugin.canBeInstalled())
 							entries.add(new Entry(plugin,set.name));
 					}
 				}
 			}
 
 			sort(sortType);
-			updateFilteredEntries();
 			restoreSelection(savedChecked, savedSelection);
 		} //}}}
 
@@ -722,12 +816,18 @@ class InstallPanel extends JPanel implements EBComponent
 				}
 			}
 			int[] rows = table.getSelectedRows();
-			for (int i=0 ; i<rows.length ; i++)
+			for (int row: rows)
 			{
-				savedSelection.add(filteredEntries.get(rows[i]).toString());
+				savedSelection.add(filteredEntries.get(row).toString());
 			}
 		} //}}}
 
+		//{{{ clearSelection() method
+		public void clearSelection()
+		{
+			restoreSelection(Collections.<String>emptySet(), Collections.<String>emptySet());
+		} //}}}
+
 		//{{{ restoreSelection() method
 		public void restoreSelection(Set<String> savedChecked, Set<String> savedSelection)
 		{
@@ -782,13 +882,14 @@ class InstallPanel extends JPanel implements EBComponent
 	//{{{ Entry class
 	private static class Entry
 	{
-		String name, installedVersion, version, author, date, description, set;
+		String name, installedVersion, version, author, date, description, set, dependencies;
 
 		long timestamp;
 		int size;
+		boolean checked;
 		boolean install;
 		PluginList.Plugin plugin;
-		List<Entry> parents = new LinkedList<Entry>();
+		List<Entry> dependents = new LinkedList<Entry>();
 
 		Entry(PluginList.Plugin plugin, String set)
 		{
@@ -803,8 +904,10 @@ class InstallPanel extends JPanel implements EBComponent
 			this.size = size;
 			this.date = branch.date;
 			this.description = plugin.description;
+			this.dependencies = branch.depsToString();
 			this.set = set;
 			this.install = false;
+			this.checked = false;
 			this.plugin = plugin;
 			SimpleDateFormat format = new SimpleDateFormat("d MMMM yyyy", Locale.ENGLISH);
 			try
@@ -817,22 +920,22 @@ class InstallPanel extends JPanel implements EBComponent
 			}
 		}
 
-		private void getParents(List<Entry> list)
+		private void getTransitiveDependents(List<Entry> list)
 		{
-			for (Entry entry : parents)
+			for (Entry entry : dependents)
 			{
 				if (entry.install && !list.contains(entry))
 				{
 					list.add(entry);
-					entry.getParents(list);
+					entry.getTransitiveDependents(list);
 				}
 			}
 		}
 
-		Entry[] getParents()
+		Entry[] getTransitiveDependents()
 		{
 			List<Entry> list = new ArrayList<Entry>();
-			getParents(list);
+			getTransitiveDependents(list);
 			Entry[] array = list.toArray(new Entry[list.size()]);
 			Arrays.sort(array,new StandardUtilities.StringCompare<Entry>(true));
 			return array;
@@ -847,11 +950,10 @@ class InstallPanel extends JPanel implements EBComponent
 
 	//{{{ PluginInfoBox class
 	/**
-	 * @TODO refactor to use the PluginDetailPanel?
+	 * TODO: refactor to use the PluginDetailPanel?
 	 */
 	private class PluginInfoBox extends JEditorPane implements ListSelectionListener
 	{
-		private final String[] params;
 		PluginInfoBox()
 		{
 			setBackground(jEdit.getColorProperty("view.bgColor"));
@@ -859,7 +961,6 @@ class InstallPanel extends JPanel implements EBComponent
 			putClientProperty(JEditorPane.HONOR_DISPLAY_PROPERTIES, true);
 			setContentType("text/html");
 			setEditable(false);
-			params = new String[3];
 			table.getSelectionModel().addListSelectionListener(this);
 		}
 
@@ -872,11 +973,25 @@ class InstallPanel extends JPanel implements EBComponent
 			{
 				Entry entry = (Entry) pluginModel.filteredEntries
 					.get(table.getSelectedRow());
-				params[0] = entry.author;
-				params[1] = entry.date;
-				params[2] = entry.description;
-				text = jEdit.getProperty("install-plugins.info", params);
-				text = text.replace("\n", "<br>");
+				String pattern = "<b>{0}</b>: {1}<br><b>{2}</b>: {3}<br>{4}<br><br><b>{5}</b>:<br>{6}";
+				List<String> params = new ArrayList<String>();
+				params.add(jEdit.getProperty("install-plugins.info.author", "Author"));
+				params.add(entry.author);
+				params.add(jEdit.getProperty("install-plugins.info.released", "Released"));
+				params.add(entry.date);
+				params.add(entry.description);
+				if (entry.dependencies == null || entry.dependencies.isEmpty())
+				{
+					pattern = "<b>{0}</b>: {1}<br><b>{2}</b>: {3} {4}";
+				} 
+				else
+				{
+					params.add(jEdit.getProperty("install-plugins.info.depends", "Depends on"));
+					StringList sl = StringList.split(entry.dependencies, "\n");
+					params.add(sl.join(", "));
+					// params.add(entry.dependencies.replaceAll("\n", ", "));
+				}
+				text = MessageFormat.format(pattern, params.toArray());
 			}
 			setText(text);
 			setCaretPosition(0);
@@ -900,7 +1015,7 @@ class InstallPanel extends JPanel implements EBComponent
 		{
 			if (e.getType() == TableModelEvent.UPDATE)
 			{
-				if(pluginModel.isDownloadingList())
+				if(isDownloadingList())
 					return;
 
 				size = 0;
@@ -947,7 +1062,7 @@ class InstallPanel extends JPanel implements EBComponent
 		@Override
 		public void tableChanged(TableModelEvent e)
 		{
-			if(pluginModel.isDownloadingList())
+			if(isDownloadingList())
 				return;
 
 			setEnabled(pluginModel.getRowCount() != 0);
@@ -1045,7 +1160,7 @@ class InstallPanel extends JPanel implements EBComponent
 		public void actionPerformed(ActionEvent e)
 		{
 			pluginSet.clear();
-			pluginModel.restoreSelection(new HashSet<String>(), new HashSet<String>());
+			pluginModel.clearSelection();
 			jEdit.unsetProperty(PluginManager.PROPERTY_PLUGINSET);
 			chooseButton.updateUI();
 		} //}}}
@@ -1065,7 +1180,7 @@ class InstallPanel extends JPanel implements EBComponent
 		@Override
 		public void actionPerformed(ActionEvent evt)
 		{
-			if(pluginModel.isDownloadingList())
+			if(isDownloadingList())
 				return;
 
 			boolean downloadSource = jEdit.getBooleanProperty(
@@ -1092,7 +1207,7 @@ class InstallPanel extends JPanel implements EBComponent
 				Entry entry = (Entry)pluginModel.entries.get(i);
 				if (entry.install)
 				{
-					entry.plugin.install(roster,installDirectory,downloadSource);
+					entry.plugin.install(roster,installDirectory,downloadSource, !entry.checked);
 					if (updates)
 						entry.plugin.getCompatibleBranch().satisfyDependencies(
 						roster,installDirectory,downloadSource);
@@ -1124,7 +1239,7 @@ class InstallPanel extends JPanel implements EBComponent
 		@Override
 		public void tableChanged(TableModelEvent e)
 		{
-			if(pluginModel.isDownloadingList())
+			if(isDownloadingList())
 				return;
 
 			if (e.getType() == TableModelEvent.UPDATE)
@@ -1183,26 +1298,7 @@ class InstallPanel extends JPanel implements EBComponent
 					}
 					break;
 				case COLUMN_VERSION:
-					// lets avoid NPE. Maybe we should move
-					// this code to StandardUtilities.compareStrings
-					if (e1.version == e2.version)
-					{
-						result = 0;
-					}
-					else if (e1.version == null)
-					{
-						result = -1;
-					}
-					else if(e2.version == null)
-					{
-						result = 1;
-					}
-					else
-					{
-						result = StandardUtilities.compareStrings(e1.version,
-											  e2.version,
-											  true);
-					}
+					result = StandardUtilities.compareStrings(e1.version, e2.version, true);
 					break;
 				case COLUMN_SIZE:
 					result = (e1.size < e2.size)
@@ -1341,7 +1437,6 @@ class InstallPanel extends JPanel implements EBComponent
 				? (model.sortDirection == 1) ? ASC_ICON : DESC_ICON
 				: null;
 			l.setIcon(icon);
-			// l.setHorizontalTextPosition(l.LEADING);
 			return l;
 		}
 	} //}}}
