@@ -109,7 +109,7 @@ public class ManagePanel extends JPanel
 		table = new JTable(pluginModel = new PluginTableModel());
 		table.setShowGrid(false);
 		table.setIntercellSpacing(new Dimension(0,0));
-		table.setRowHeight(table.getRowHeight() + 2);
+		table.setRowHeight(GUIUtilities.defaultRowHeight() + 2);
 		table.setPreferredScrollableViewportSize(new Dimension(500,300));
 		table.setDefaultRenderer(Object.class, new TextRenderer(
 			(DefaultTableCellRenderer)table.getDefaultRenderer(Object.class)));
@@ -142,6 +142,8 @@ public class ManagePanel extends JPanel
 
 		JTableHeader header = table.getTableHeader();
 		header.setReorderingAllowed(false);
+		header.setDefaultRenderer(new HeaderRenderer(
+				(DefaultTableCellRenderer)header.getDefaultRenderer()));
 		HeaderMouseHandler mouseHandler = new HeaderMouseHandler();
 		header.addMouseListener(mouseHandler);
 		table.addMouseListener(mouseHandler);
@@ -253,30 +255,17 @@ public class ManagePanel extends JPanel
 	 * If the plugin is loaded use {@link org.gjt.sp.jedit.PluginJAR#getRequiredJars()}
 	 * instead
 	 *
-	 * @param jarName the jar name of the plugin
+	 * @param jarPath the path to the jar of the plugin
 	 * @return a collection containing jars path
 	 * @throws IOException if jEdit cannot generate cache
 	 * @since jEdit 4.3pre12
 	 */
-	private static Collection<String> getDeclaredJars(String jarName) throws IOException
+	private static Collection<String> getDeclaredJars(String jarPath) throws IOException
 	{
 		Collection<String> jarList = new ArrayList<String>();
-		PluginJAR pluginJAR = new PluginJAR(new File(jarName));
-		PluginJAR.PluginCacheEntry pluginCacheEntry = PluginJAR.getPluginCache(pluginJAR);
-		if (pluginCacheEntry == null)
-		{
-			pluginCacheEntry = pluginJAR.generateCache();
-		}
-		if(pluginCacheEntry == null)
-		{
-			// this happens when, for some reason, two versions
-			// of a plugin are installed, e.g when XSLT.jar and
-			// xslt.jar are both in $JEDIT_HOME/jars on Linux.
-			Log.log(Log.WARNING, ManagePanel.class,
-					"couldn't load plugin "+pluginJAR.getPath()
-					+" (most likely other version exists)");
-		}
-		else
+		PluginJAR pluginJAR = new PluginJAR(new File(jarPath));
+		PluginJAR.PluginCacheEntry pluginCacheEntry = PluginJAR.getPluginCacheEntry(jarPath);
+		if(pluginCacheEntry != null)
 		{
 			Properties cachedProperties = pluginCacheEntry.cachedProperties;
 
@@ -284,24 +273,22 @@ public class ManagePanel extends JPanel
 
 			if (jars != null)
 			{
-				String dir = MiscUtilities.getParentOfPath(pluginJAR.getPath());
-				StringTokenizer st = new StringTokenizer(jars);
-				while (st.hasMoreTokens())
+				Collection<String> jarsPaths = PluginJAR.parseJarsFilesString(pluginJAR.getPath(), jars);
+				for(String _jarPath: jarsPaths)
 				{
-					String _jarPath = MiscUtilities.constructPath(dir, st.nextToken());
 					if (new File(_jarPath).exists())
 						jarList.add(_jarPath);
 				}
 			}
 		}
-		jarList.add(jarName);
+		jarList.add(jarPath);
 		return jarList;
 	}//}}}
 
 	//{{{ Inner classes
 
 	//{{{ Entry class
-	static class Entry
+	class Entry
 	{
 		static final String LOADED = "loaded";
 		static final String NOT_LOADED = "not-loaded";
@@ -317,6 +304,9 @@ public class ManagePanel extends JPanel
 		String clazz, name, version, author, docs;
 		/** The description property of the plugin. */
 		String description;
+		/** The dependencies of the plugin. */
+		Set<String> depends;
+		
 		EditPlugin plugin;
 		/**
 		 * The jars referenced in the props file of the plugin.
@@ -341,6 +331,26 @@ public class ManagePanel extends JPanel
 			if (jEdit.getBooleanProperty("plugin." + MiscUtilities.getFileName(jar) + ".disabled"))
 				status = DISABLED;
 			else status = NOT_LOADED;
+
+			PluginJAR.PluginCacheEntry cacheEntry;
+			try
+			{
+				cacheEntry = PluginJAR.getPluginCacheEntry(jar);
+				if(cacheEntry != null)
+				{
+					clazz = cacheEntry.pluginClass;
+					Properties props = cacheEntry.cachedProperties;
+					name = props.getProperty("plugin."+clazz+".name");
+					version = props.getProperty("plugin."+clazz+".version");
+					author = props.getProperty("plugin."+clazz+".author");
+					docs = props.getProperty("plugin."+clazz+".docs");
+					description = props.getProperty("plugin."+clazz+".description");
+				}
+			}
+			catch (IOException e)
+			{
+				Log.log(Log.WARNING, "Unable to load cache for "+jar, e);
+			}
 		}
 
 		/**
@@ -365,39 +375,38 @@ public class ManagePanel extends JPanel
 				author = jEdit.getProperty("plugin."+clazz+".author");
 				docs = jEdit.getProperty("plugin."+clazz+".docs");
 				description = jEdit.getProperty("plugin."+clazz+".description");
-				String jarsProp = jEdit.getProperty("plugin."+clazz+".jars");
-
-				if(jarsProp != null)
-				{
-					String directory = MiscUtilities.getParentOfPath(this.jar);
-
-					StringTokenizer st = new StringTokenizer(jarsProp);
-					while(st.hasMoreElements())
-					{
-						jars.add(MiscUtilities.constructPath(
-							directory,st.nextToken()));
-					}
-				}
-
-				String filesProp = jEdit.getProperty("plugin."+clazz+".files");
-
-				if(filesProp != null)
-				{
-					String directory = MiscUtilities.getParentOfPath(this.jar);
-
-					StringTokenizer st = new StringTokenizer(filesProp);
-					while(st.hasMoreElements())
-					{
-						jars.add(MiscUtilities.constructPath(
-							directory,st.nextToken()));
-					}
-				}
+				jars.addAll(jar.getJars());
+				jars.addAll(jar.getFiles());
 			}
 			else
 			{
 				status = LOADED;
 			}
 		}
+		
+		/**
+		 * @return A list of the names of the dependencies, e.g. ErrorList or ProjectViewer.
+		 */
+		public Set<String> getDependencies() 
+		{
+			if (plugin == null)
+				return null;
+			Set<String> depends = null;
+			PluginJAR jar = plugin.getPluginJAR();
+			String cn = plugin.getClassName();
+			Set<String> requiredJars = jar.getDependencies(cn);
+			if (requiredJars != null && !requiredJars.isEmpty())
+			{
+				depends = new HashSet<String>();
+				for (String dep : requiredJars)
+				{
+					Entry e = pluginModel.getEntry(dep);
+					if (e != null)
+						depends.add(e.name);
+				}
+			}
+			return depends;
+		}
 	} //}}}
 
 	//{{{ PluginTableModel class
@@ -407,6 +416,7 @@ public class ManagePanel extends JPanel
 		private int sortType = EntryCompare.NAME;
 		private ConcurrentHashMap<String, Object> unloaded;
 		// private HashSet<String> unloaded;
+		private int sortDirection = 1;
 
 		//{{{ Constructor
 		PluginTableModel()
@@ -459,6 +469,19 @@ public class ManagePanel extends JPanel
 			return entries.get(rowIndex);
 		} //}}}
 
+		//{{{ getEntry() method
+		public Entry getEntry(String classname)
+		{
+			if (classname == null || classname.isEmpty())
+				return null;
+			for (Entry entry : entries)
+			{
+				if (classname.equals(entry.clazz))
+					return entry;
+			}
+			return null;
+		} //}}}
+
 		//{{{ getRowCount() method
 		@Override
 		public int getRowCount()
@@ -529,41 +552,41 @@ public class ManagePanel extends JPanel
 
 		//{{{ setValueAt() method
 		@Override
-		public void setValueAt(Object value, int rowIndex,
-			int columnIndex)
+		public void setValueAt(final Object value, int rowIndex,
+			final int columnIndex)
 		{
-			Entry entry = entries.get(rowIndex);
-			if(columnIndex == 0)
+			final Entry entry = entries.get(rowIndex);
+			SwingUtilities.invokeLater(new Runnable()
 			{
-				PluginJAR jar = jEdit.getPluginJAR(entry.jar);
-				if(jar == null)
+				@Override
+				public void run()
 				{
-					if(value.equals(Boolean.FALSE))
-						return;
-
-					PluginJAR load = PluginJAR.load(entry.jar, true);
-					if (load == null)
+					if(columnIndex == 0)
 					{
-						GUIUtilities.error(ManagePanel.this, "plugin-load-error", null);
+						PluginJAR jar = jEdit.getPluginJAR(entry.jar);
+						if(jar == null)
+						{
+							if(value.equals(Boolean.FALSE))
+								return;
+
+							PluginJAR load = PluginJAR.load(entry.jar, true);
+							if (load == null)
+							{
+								GUIUtilities.error(ManagePanel.this, "plugin-load-error", null);
+							}
+						}
+						else
+						{
+							if(value.equals(Boolean.TRUE))
+								return;
+
+							unloadPluginJARWithDialog(jar);
+						}
 					}
+
+					update();
 				}
-				else
-				{
-					if(value.equals(Boolean.TRUE))
-						return;
-
-					unloadPluginJARWithDialog(jar);
-				}
-			}
-
-			update();
-		} //}}}
-
-		//{{{ setSortType() method
-		public void setSortType(int type)
-		{
-			sortType = type;
-			sort(type);
+			});
 		} //}}}
 
 		//{{{ sort() method
@@ -571,9 +594,17 @@ public class ManagePanel extends JPanel
 		{
 			List<String> savedSelection = new ArrayList<String>();
 			saveSelection(savedSelection);
-			Collections.sort(entries,new EntryCompare(type));
+
+			if (sortType != type)
+			{
+				sortDirection = 1;
+			}
+			sortType = type;
+
+			Collections.sort(entries, new EntryCompare(type, sortDirection));
 			fireTableChanged(new TableModelEvent(this));
 			restoreSelection(savedSelection);
+			table.getTableHeader().repaint();
 		}
 		//}}}
 
@@ -630,28 +661,44 @@ public class ManagePanel extends JPanel
 		{
 			// unloaded = new HashSet<String>();
 			unloaded = new ConcurrentHashMap<String, Object>();
-			String[] dependents = jar.getDependentPlugins();
+			String[] dependents = jar.getAllDependentPlugins();
 			if(dependents.length == 0)
+			{
 				unloadPluginJAR(jar);
+			}
 			else
 			{
 				List<String> closureSet = new LinkedList<String>();
+				dependents = jar.getDependentPlugins();
 				PluginJAR.transitiveClosure(dependents, closureSet);
-				List<String> listModel = new ArrayList<String>();
-				listModel.addAll(closureSet);
-				Collections.sort(listModel, new StandardUtilities.StringCompare<String>(true));
-
-				int button = GUIUtilities.listConfirm(window,"plugin-manager.dependency",
-					new String[] { jar.getFile().getName() }, listModel.toArray());
-				if(button == JOptionPane.YES_OPTION)
+				List<String> listModel = new ArrayList<String>(new HashSet<String>(closureSet));	// remove dupes
+				boolean confirm = true;
+				if (!listModel.isEmpty())
+				{
+					// show confirmation dialog listing dependencies to be unloaded
+					Collections.sort(listModel, new StandardUtilities.StringCompare<String>(true));
+					int button = GUIUtilities.listConfirm(window,"plugin-manager.dependency",
+						new String[] { jar.getFile().getName() }, listModel.toArray());
+					confirm = button == JOptionPane.YES_OPTION;
+				}
+				if (confirm)
+				{
+					String[] optionals = jar.getOptionallyDependentPlugins();
 					unloadPluginJAR(jar);
+					// reload the optionally dependent plugins since they can run 
+					// without this plugin
+					for (String opt : optionals) 
+					{
+						PluginJAR.load(opt, true);	
+					}
+				}
 			}
 		} //}}}
 
 		//{{{ unloadPluginJAR() method
 		private void unloadPluginJAR(PluginJAR jar)
 		{
-			String[] dependents = jar.getDependentPlugins();
+			String[] dependents = jar.getAllDependentPlugins();
 			for (String dependent : dependents)
 			{
 				if (!unloaded.containsKey(dependent))
@@ -679,10 +726,8 @@ public class ManagePanel extends JPanel
 			if (table != null)
 			{
 				int[] rows = table.getSelectedRows();
-				for (int i=0 ; i<rows.length ; i++)
-				{
-					savedSelection.add(entries.get(rows[i]).jar);
-				}
+				for (int row : rows)
+					savedSelection.add(entries.get(row).jar);
 			}
 		} //}}}
 
@@ -944,13 +989,19 @@ public class ManagePanel extends JPanel
 
 			for (String jar : jarsToRemove)
 			{
-				listModel.add(jar);
-				roster.addRemove(jar);
+				if(new File(jar).exists())
+				{
+					listModel.add(jar);
+					roster.addRemove(jar);
+				}
 			}
 
+			Object[] sortedConfirm = listModel.toArray();
+			Arrays.sort(sortedConfirm);
+
 			int button = GUIUtilities.listConfirm(window,
 				"plugin-manager.remove-confirm",
-				null,listModel.toArray());
+				null, sortedConfirm);
 			if(button == JOptionPane.YES_OPTION)
 			{
 
@@ -1065,11 +1116,7 @@ public class ManagePanel extends JPanel
 
 					if (jars != null)
 					{
-						StringTokenizer st = new StringTokenizer(jars);
-						while (st.hasMoreTokens())
-						{
-							neededJars.add(st.nextToken());
-						}
+						neededJars.addAll(PluginJAR.parseJarsFilesStringNames(jars));
 					}
 				}
 				catch (IOException e1)
@@ -1105,11 +1152,8 @@ public class ManagePanel extends JPanel
 				return;
 
 			Roster roster = new Roster();
-			for (int i = 0; i < mustRemove.size(); i++)
-			{
-				String entry = mustRemove.get(i);
+			for (String entry : mustRemove)
 				roster.addRemove(jarlibs.get(entry));
-			}
 
 			roster.performOperationsInAWTThread(window);
 			pluginModel.update();
@@ -1183,27 +1227,41 @@ public class ManagePanel extends JPanel
 	private static class EntryCompare implements Comparator<Entry>
 	{
 		public static final int NAME = 1;
-		public static final int STATUS = 2;
+		public static final int VERSION = 2;
+		public static final int STATUS = 3;
+		public static final int DATA = 4;
 
 		private final int type;
+		private final int direction;
 
-		EntryCompare(int type)
+		EntryCompare(int type, int direction)
 		{
 			this.type = type;
+			this.direction = direction;
 		}
 
 		@Override
 		public int compare(Entry e1, Entry e2)
 		{
-			if (type == NAME)
-				return compareNames(e1,e2);
-			else
+			int result;
+			switch(type)
 			{
-				int result;
-				if ((result = e1.status.compareToIgnoreCase(e2.status)) == 0)
-					return compareNames(e1,e2);
-				return result;
+			case NAME:
+				result = compareNames(e1,e2);
+				break;
+			case VERSION:
+				result = StandardUtilities.compareStrings(e1.version, e2.version, true);
+				break;
+			case STATUS:
+				result = e1.status.compareToIgnoreCase(e2.status);
+				break;
+			case DATA:
+				result = StandardUtilities.compareStrings(e1.dataSize,e2.dataSize, false);
+				break;
+			default:
+				throw new IllegalStateException("Invalid sort type "+type);
 			}
+			return result * direction;
 		}
 
 		private static int compareNames(Entry e1, Entry e2)
@@ -1221,6 +1279,7 @@ public class ManagePanel extends JPanel
 
 			return s1.compareToIgnoreCase(s2);
 		}
+
 	} //}}}
 
 	//{{{ HeaderMouseHandler class
@@ -1231,17 +1290,9 @@ public class ManagePanel extends JPanel
 		{
 			if (evt.getSource() == table.getTableHeader())
 			{
-				switch(table.getTableHeader().columnAtPoint(evt.getPoint()))
-				{
-					case 1:
-						pluginModel.setSortType(EntryCompare.NAME);
-						break;
-					case 3:
-						pluginModel.setSortType(EntryCompare.STATUS);
-						break;
-					default:
-						break;
-				}
+				int column = table.getTableHeader().columnAtPoint(evt.getPoint());
+				pluginModel.sortDirection *= -1;
+				pluginModel.sort(column);
 			}
 			else
 			{
@@ -1329,10 +1380,11 @@ public class ManagePanel extends JPanel
 				break;
 			case EDIT_PLUGIN:
 				int[] rows = table.getSelectedRows();
-				for (int i = 0; i < rows.length; i++)
+				for (int row : rows)
 				{
-					Object st = pluginModel.getValueAt(rows[i], 0);
-					pluginModel.setValueAt(st.equals(Boolean.FALSE), rows[i], 0);
+					Object st = pluginModel.getValueAt(row, 0);
+					pluginModel.setValueAt(
+						st.equals(Boolean.FALSE), row, 0);
 				}
 				break;
 			case CLOSE_PLUGIN_MANAGER:
@@ -1363,6 +1415,31 @@ public class ManagePanel extends JPanel
 		}
 	} //}}}
 
+	//{{{ HeaderRenderer
+	private static class HeaderRenderer extends DefaultTableCellRenderer
+	{
+		private final DefaultTableCellRenderer tcr;
+
+		HeaderRenderer(DefaultTableCellRenderer tcr)
+		{
+			this.tcr = tcr;
+		}
+
+		@Override
+		public Component getTableCellRendererComponent(JTable table, Object value,
+							       boolean isSelected, boolean hasFocus,
+							       int row, int column)
+		{
+			JLabel l = (JLabel)tcr.getTableCellRendererComponent(table,value,isSelected,hasFocus,row,column);
+			PluginTableModel model = (PluginTableModel) table.getModel();
+			Icon icon = (column == model.sortType)
+				? (model.sortDirection == 1) ? InstallPanel.ASC_ICON : InstallPanel.DESC_ICON
+				: null;
+			l.setIcon(icon);
+			return l;
+		}
+	} //}}}
+
 	//{{{ TableSelectionListener class
 	private class TableSelectionListener implements ListSelectionListener
 	{
