@@ -30,6 +30,7 @@ import java.net.*;
 import java.util.zip.*;
 import java.util.*;
 import org.gjt.sp.jedit.*;
+import org.gjt.sp.jedit.msg.PluginUpdate;
 import org.gjt.sp.util.Log;
 import org.gjt.sp.util.IOUtilities;
 
@@ -37,7 +38,7 @@ import static org.gjt.sp.jedit.io.FileVFS.recursiveDelete;
 //}}}
 
 /**
- * @author $Id: Roster.java 22357 2012-10-13 04:58:01Z ezust $
+ * @author $Id: Roster.java 24071 2015-09-16 19:51:55Z kerik-sf $
  */
 class Roster
 {
@@ -65,6 +66,12 @@ class Roster
 		addOperation(new Install(installed,url,installDirectory,size));
 	} //}}}
 
+	//{{{ addLoad() method
+	void addLoad(String path)
+	{
+		toLoad.add(path);
+	} //}}}
+
 	//{{{ getOperation() method
 	public Operation getOperation(int i)
 	{
@@ -86,13 +93,12 @@ class Roster
 	//{{{ performOperationsInWorkThread() method
 	void performOperationsInWorkThread(PluginManagerProgress progress)
 	{
-		for(int i = 0; i < operations.size(); i++)
+		for (Operation op : operations)
 		{
-			Operation op = operations.get(i);
 			op.runInWorkThread(progress);
 			progress.done();
 
-			if(Thread.interrupted())
+			if (Thread.interrupted())
 				return;
 		}
 	} //}}}
@@ -100,40 +106,31 @@ class Roster
 	//{{{ performOperationsInAWTThread() method
 	void performOperationsInAWTThread(Component comp)
 	{
-		for(int i = 0; i < operations.size(); i++)
-		{
-			Operation op = operations.get(i);
+		for (Operation op : operations)
 			op.runInAWTThread(comp);
-		}
 
 		// add the JARs before checking deps since dep check might
 		// require all JARs to be present
-		for(int i = 0; i < toLoad.size(); i++)
+		for (String pluginName : toLoad)
 		{
-			String pluginName = toLoad.get(i);
-			if(jEdit.getPluginJAR(pluginName) != null)
-			{
-				Log.log(Log.WARNING,this,"Already loaded: "
-					+ pluginName);
-			}
+			if (jEdit.getPluginJAR(pluginName) != null)
+				Log.log(Log.WARNING, this, "Already loaded: " + pluginName);
 			else
 				jEdit.addPluginJAR(pluginName);
 		}
 
-		for(int i = 0; i < toLoad.size(); i++)
+		for (String pluginName : toLoad)
 		{
-			String pluginName = toLoad.get(i);
 			PluginJAR plugin = jEdit.getPluginJAR(pluginName);
-			if(plugin != null)
+			if (plugin != null)
 				plugin.checkDependencies();
 		}
 
 		// now activate the plugins
-		for(int i = 0; i < toLoad.size(); i++)
+		for (String pluginName : toLoad)
 		{
-			String pluginName = toLoad.get(i);
 			PluginJAR plugin = jEdit.getPluginJAR(pluginName);
-			if(plugin != null)
+			if (plugin != null)
 				plugin.activatePluginIfNecessary();
 		}
 	} //}}}
@@ -147,9 +144,9 @@ class Roster
 	//{{{ addOperation() method
 	private void addOperation(Operation op)
 	{
-		for(int i = 0; i < operations.size(); i++)
+		for (Operation operation : operations)
 		{
-			if(operations.get(i).equals(op))
+			if (operation.equals(op))
 				return;
 		}
 
@@ -212,23 +209,29 @@ class Roster
 
 			toLoad.remove(this.jar);
 
-			// move JAR first
 			File jarFile = new File(this.jar);
 			File srcFile = new File(this.jar.substring(0, this.jar.length() - 4));
 
-			Log.log(Log.NOTICE,this,"Deleting " + jarFile);
-
-			boolean ok = jarFile.delete();
-
-			if(srcFile.exists())
+			if(jarFile.exists())
 			{
-				ok &= recursiveDelete(srcFile);
-			}
+				Log.log(Log.NOTICE,this,"Deleting " + jarFile);
 
-			if(!ok)
-			{
-				String[] args = {this.jar};
-				GUIUtilities.error(comp,"plugin-manager.remove-failed",args);
+				boolean ok = jarFile.delete();
+				if (ok)
+				{
+					EditBus.send(new PluginUpdate(jarFile, PluginUpdate.REMOVED, false));
+				}
+
+				if(srcFile.exists())
+				{
+					ok &= recursiveDelete(srcFile);
+				}
+
+				if(!ok)
+				{
+					String[] args = {this.jar};
+					GUIUtilities.error(comp,"plugin-manager.remove-failed",args);
+				}
 			}
 		} //}}}
 
@@ -304,9 +307,29 @@ class Roster
 			if(path == null)
 				return;
 
-			// if download OK, remove existing version
+			/* if download OK, remove existing version
+			 * and bundled jars and files */
 			if(installed != null)
-				new Remove(installed).runInAWTThread(comp);
+			{
+				PluginJAR pluginJar = jEdit.getPluginJAR(installed);
+				Collection<String> libs = new LinkedList<>();
+				libs.add(installed);
+				if(pluginJar == null)
+				{
+					Log.log(Log.ERROR, Roster.Remove.class,
+						 "unable to get PluginJAR for "+installed);
+				}
+				else
+				{
+					 libs.addAll(pluginJar.getJars());
+					 libs.addAll(pluginJar.getFiles());
+				}
+
+				for(String lib: libs)
+				{
+					new Remove(lib).runInAWTThread(comp);
+				}
+			}
 
 			ZipFile zipFile = null;
 
