@@ -50,7 +50,7 @@ import org.gjt.sp.util.Log;
  * @see TextArea
  *
  * @author Mike Dillon and Slava Pestov
- * @version $Id: Gutter.java 21831 2012-06-18 22:54:17Z ezust $
+ * @version $Id: Gutter.java 23977 2015-08-08 22:01:12Z daleanson $
  */
 public class Gutter extends JComponent implements SwingConstants
 {
@@ -185,6 +185,8 @@ public class Gutter extends JComponent implements SwingConstants
 		}
 	
 		int y = clip.y - clip.y % lineHeight;
+		if (y == 0)
+			y = textArea.getPainter().getLineExtraSpacing();
 
 		extensionMgr.paintScreenLineRange(textArea,gfx,
 			firstLine,lastLine,y,lineHeight);
@@ -950,12 +952,14 @@ public class Gutter extends JComponent implements SwingConstants
 				if (e.getX() >= FOLD_MARKER_SIZE)
 				{
 					selectionStart = textArea.getLineStartOffset(line);
+					int selectionEnd = getFoldEndOffset(line);
 					Selection s = new Selection.Range(
-						selectionStart, getFoldEndOffset(line));
+						selectionStart, selectionEnd);
 					if(textArea.isMultipleSelectionEnabled())
 						textArea.addToSelection(s);
 					else
 						textArea.setSelection(s);
+					textArea.moveCaretPosition(selectionEnd, false);
 					selectLines = true;
 					selAnchorLine = line;
 					return;
@@ -1086,11 +1090,13 @@ public class Gutter extends JComponent implements SwingConstants
 				{
 					selStart = textArea.getLineStartOffset(line);
 					selEnd = getFoldEndOffset(selAnchorLine);
+					textArea.moveCaretPosition(selStart, false);
 				}
 				else
 				{
 					selStart = textArea.getLineStartOffset(selAnchorLine);
 					selEnd = getFoldEndOffset(line);
+					textArea.moveCaretPosition(selEnd, false);
 				}
 
 				textArea.resizeSelection(selStart, selEnd, 0, false);
