@@ -97,7 +97,7 @@ import org.gjt.sp.util.SyntaxUtilities;
  * @author Slava Pestov
  * @author John Gellene (API documentation)
    @author Matthieu Casanova
- * @version $Id: StandaloneTextArea.java 22357 2012-10-13 04:58:01Z ezust $
+ * @version $Id: StandaloneTextArea.java 23821 2015-01-04 14:31:09Z ezust $
  */
 public class StandaloneTextArea extends TextArea
 {
@@ -269,6 +269,8 @@ public class StandaloneTextArea extends TextArea
 			getColorProperty("view.structureHighlightColor"));
 		painter.setEOLMarkersPainted(getBooleanProperty(
 			"view.eolMarkers"));
+		String emc = getProperty("view.eolMarkerChar");
+		if (emc.length() > 0) painter.setEOLMarkerChar(emc);
 		painter.setEOLMarkerColor(
 			getColorProperty("view.eolMarkerColor"));
 		painter.setWrapGuidePainted(getBooleanProperty(
@@ -515,13 +517,13 @@ public class StandaloneTextArea extends TextArea
 			"folding",
 			"collapseFolds"
 		};
-		for (int i = 0; i < bufferProperties.length; i++)
+		for (String bufferProperty : bufferProperties)
 		{
-			String value = getProperty("buffer." + bufferProperties[i]);
+			String value = getProperty("buffer." + bufferProperty);
 			if (value == null)
-				buffer.unsetProperty(bufferProperties[i]);
+				buffer.unsetProperty(bufferProperty);
 			else
-				buffer.setProperty(bufferProperties[i], value);
+				buffer.setProperty(bufferProperty, value);
 		}
 		buffer.propertiesChanged();
 	} // }}}
@@ -589,7 +591,7 @@ public class StandaloneTextArea extends TextArea
 	 * The actionSet for standalone textArea.
 	 * @author Matthieu Casanova
 	 */
-	protected static class StandaloneActionSet extends JEditActionSet<JEditBeanShellAction>
+	public static class StandaloneActionSet extends JEditActionSet<JEditBeanShellAction>
 	{
 		private final IPropertyManager iPropertyManager;
 		private final TextArea textArea;
@@ -620,11 +622,11 @@ public class StandaloneTextArea extends TextArea
 
 		@Override
 		protected JEditBeanShellAction createBeanShellAction(String actionName,
-								     String code,
-								     String selected,
-								     boolean noRepeat,
-								     boolean noRecord,
-								     boolean noRememberLast)
+									 String code,
+									 String selected,
+									 boolean noRepeat,
+									 boolean noRecord,
+									 boolean noRememberLast)
 		{
 			return new JEditBeanShellAction(actionName,code,selected,noRepeat,noRecord,noRememberLast);
 		}
